@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -55,23 +55,30 @@ CompletingEdit::CompletingEdit(QWidget *parent)
 	  pHunspell(NULL), spellingCodec(NULL)
 {
 	if (sharedCompleter == NULL) { // initialize shared (static) members
+		qreal bgR, bgG, bgB;
+		qreal fgR, fgG, fgB;
+		
 		sharedCompleter = new QCompleter(qApp);
 		sharedCompleter->setCompletionMode(QCompleter::InlineCompletion);
 		sharedCompleter->setCaseSensitivity(Qt::CaseInsensitive);
 		loadCompletionFiles(sharedCompleter);
 
+		palette().color(QPalette::Active, QPalette::Base).getRgbF(&bgR, &bgG, &bgB);
+		palette().color(QPalette::Active, QPalette::Text).getRgbF(&fgR, &fgG, &fgB);
+
 		currentCompletionFormat = new QTextCharFormat;
-		currentCompletionFormat->setBackground(QColor("yellow").lighter(160));
+		currentCompletionFormat->setBackground(QColor::fromRgbF(.75 * bgR + .25 * fgR, .75 * bgG + .25 * fgG, .75 * bgB + .25 * fgB));
 		braceMatchingFormat = new QTextCharFormat;
 		braceMatchingFormat->setBackground(QColor("orange"));
+
 		currentLineFormat = new QTextCharFormat;
-		currentLineFormat->setBackground(QColor("yellow").lighter(180));
+		currentLineFormat->setBackground(QColor::fromRgbF(.9 * bgR + .1 * fgR, .9 * bgG + .1 * fgG, .9 * bgB + .1 * fgB));
 		currentLineFormat->setProperty(QTextFormat::FullWidthSelection, true);
 
 		QSETTINGS_OBJECT(settings);
 		highlightCurrentLine = settings.value("highlightCurrentLine", true).toBool();
 	}
-	
+		
 	loadIndentModes();
 	loadSmartQuotesModes();
 	
@@ -130,6 +137,8 @@ void CompletingEdit::mousePressEvent(QMouseEvent *e)
 		return;
 	}
 
+	int proximityToPrev = (e->pos() - clickPos).manhattanLength();
+
 	mouseMode = normalSelection;
 	clickPos = e->pos();
 	if (e->modifiers() & Qt::ShiftModifier) {
@@ -139,7 +148,7 @@ void CompletingEdit::mousePressEvent(QMouseEvent *e)
 		return;
 	}
 
-	if (clickTimer.isActive() && (e->pos() - clickPos).manhattanLength() < qApp->startDragDistance())
+	if (clickTimer.isActive() && proximityToPrev < qApp->startDragDistance())
 		++clickCount;
 	else
 		clickCount = 1;
@@ -595,6 +604,7 @@ void CompletingEdit::maybeSmartenQuote(int offset)
 	if (smartQuotesMode < 0 || smartQuotesMode >= quotesModes->count())
 		return;
 	const QuoteMapping& mappings = quotesModes->at(smartQuotesMode).mappings;
+	QString replacement;
 
 	const QString& text = document()->toPlainText();
 	if (offset < 0 || offset >= text.length())
@@ -608,21 +618,59 @@ void CompletingEdit::maybeSmartenQuote(int offset)
 	if (iter == mappings.end())
 		return;
 	
+	replacement = iter.value().second;
 	if (offset == 0) {
-		cursor.insertText(iter.value().first);
-		return;
+		// always use opening quotes at the beginning of the document
+		replacement = iter.value().first;
 	}
-	if (offset == text.length() - 1) {
-		cursor.insertText(iter.value().second);
-		return;
+	else {
+		if (text[offset - 1].isSpace())
+			replacement = iter.value().first;
+		
+		// after opening brackets, also use opening quotes
+		if (text[offset - 1] == '{' || text[offset - 1] == '[' || text[offset - 1] == '(')
+			replacement = iter.value().first;
 	}
-	QChar prevChar = text[offset - 1];
-	QChar nextChar = text[offset + 1];
-	if (prevChar.isSpace()) {
-		cursor.insertText(iter.value().first);
+	
+	cursor.insertText(replacement);
+}
+
+void CompletingEdit::smartenQuotes()
+{
+	if (smartQuotesMode < 0 || smartQuotesMode >= quotesModes->count())
 		return;
+	const QuoteMapping& mappings = quotesModes->at(smartQuotesMode).mappings;
+
+	const QString& text = document()->toPlainText();
+
+	QTextCursor curs = textCursor();
+	int selStart = curs.selectionStart();
+	int selEnd = curs.selectionEnd();
+	bool changed = false;
+	for (int offset = selEnd; offset > selStart; ) {
+		--offset;
+		QChar ch = text[offset];
+		QuoteMapping::const_iterator iter = mappings.find(ch);
+		if (iter == mappings.end())
+			continue;
+
+		if (!changed) {
+			curs.beginEditBlock();
+			changed = true;
+		}
+		curs.setPosition(offset, QTextCursor::MoveAnchor);
+		curs.setPosition(offset + 1, QTextCursor::KeepAnchor);
+		const QString& replacement((offset == 0 || text[offset - 1].isSpace()) ?
+								   iter.value().first : iter.value().second);
+		curs.insertText(replacement);
+		selEnd += replacement.length() - 1;
+	}
+	if (changed) {
+		curs.endEditBlock();
+		curs.setPosition(selStart, QTextCursor::MoveAnchor);
+		curs.setPosition(selEnd, QTextCursor::KeepAnchor);
+		setTextCursor(curs);
 	}
-	cursor.insertText(iter.value().second);
 }
 
 void CompletingEdit::handleCompletionShortcut(QKeyEvent *e)
@@ -849,6 +897,8 @@ void CompletingEdit::contextMenuEvent(QContextMenuEvent *event)
 {
 	QMenu *menu = createStandardContextMenu();
 
+	QAction *defaultAction = NULL;
+
 	QAction *act = new QAction(tr("Jump to PDF"), menu);
 	act->setData(QVariant(cursorForPosition(event->pos()).blockNumber() + 1));
 	connect(act, SIGNAL(triggered()), this, SLOT(jumpToPdf()));
@@ -876,6 +926,8 @@ void CompletingEdit::contextMenuEvent(QContextMenuEvent *event)
 						mapper->setMapping(act, str);
 						menu->insertAction(sep, act);
 						free(suggestionList[i]);
+						if (!defaultAction)
+							defaultAction = act;
 					}
 					free(suggestionList);
 					connect(mapper, SIGNAL(mapped(const QString&)), this, SLOT(correction(const QString&)));
@@ -891,7 +943,7 @@ void CompletingEdit::contextMenuEvent(QContextMenuEvent *event)
 		}
 	}
 	
-	menu->exec(event->globalPos());
+	menu->exec(event->globalPos(), defaultAction);
 	delete menu;
 }
 
