@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <QTextBlock>
 #include <QFileInfo>
 #include <QKeyEvent>
+#include <QShortcut>
 #if QT_VERSION >= 0x040400
 #include <QTextBoundaryFinder>
 #endif
@@ -422,6 +423,42 @@ SearchResults::SearchResults(QWidget* parent)
 {
 	setupUi(this);
 	connect(table, SIGNAL(itemSelectionChanged()), this, SLOT(showSelectedEntry()));
+	connect(table, SIGNAL(itemPressed(QTableWidgetItem*)), this, SLOT(showEntry(QTableWidgetItem*)));
+	QShortcut *sc;
+	sc = new QShortcut(Qt::Key_Escape, table);
+	sc->setContext(Qt::WidgetShortcut);
+	connect(sc, SIGNAL(activated()), this, SLOT(goToSourceAndClose()));
+	sc = new QShortcut(Qt::Key_Return, table);
+	sc->setContext(Qt::WidgetShortcut);
+	connect(sc, SIGNAL(activated()), this, SLOT(showSelectedEntry()));
+}
+
+void SearchResults::goToSource()
+{
+	QList<QTableWidgetSelectionRange> ranges = table->selectedRanges();
+	if (ranges.count() == 0)
+		return;
+	int row = ranges.first().topRow();
+	QString fileName;
+	QTableWidgetItem* item = table->item(row, 0);
+	if (!item)
+		return;
+	fileName = item->toolTip();
+	
+	if (!fileName.isEmpty()) {
+		QWidget *theDoc = TeXDocument::openDocument(fileName);
+		if (theDoc) {
+			QTextEdit *editor = theDoc->findChild<QTextEdit*>("textEdit");
+			if (editor)
+				editor->setFocus();
+		}
+	}
+}
+
+void SearchResults::goToSourceAndClose()
+{
+	goToSource();
+	deleteLater();
 }
 
 #define MAXIMUM_CHARACTERS_BEFORE_SEARCH_RESULT 40
@@ -441,7 +478,7 @@ void SearchResults::presentResults(const QString& searchText,
 	}
 
 	SearchResults* resultsWindow = new SearchResults(parent);
-	resultsWindow->setWindowTitle(resultsWindow->windowTitle() + " - " + searchText);
+	resultsWindow->setWindowTitle(tr("Search Results - %1 (%2 found)").arg(searchText).arg(results.count()));
 
 	resultsWindow->table->setRowCount(results.count());
 	int i = 0;
@@ -523,20 +560,15 @@ void SearchResults::presentResults(const QString& searchText,
 	resultsWindow->show();
 }
 
-void SearchResults::showSelectedEntry()
+void SearchResults::showEntry(QTableWidgetItem * item)
 {
-	QList<QTableWidgetSelectionRange> ranges = table->selectedRanges();
-	if (ranges.count() == 0)
-		return;
-	int row = ranges.first().topRow();
-	QString fileName;
-	int	lineNo = 1;
-	QTableWidgetItem* item = table->item(row, 0);
 	if (!item)
 		return;
-	fileName = item->toolTip();
+	int row = item->row();
+	item = table->item(row, 0);
+	QString fileName = item->toolTip();
 	item = table->item(row, 1);
-	lineNo = item->text().toInt();
+	int lineNo = item->text().toInt();
 	item = table->item(row, 2);
 	int selStart = item->text().toInt();
 	item = table->item(row, 3);
@@ -546,6 +578,18 @@ void SearchResults::showSelectedEntry()
 		TeXDocument::openDocument(fileName, false, true, lineNo, selStart, selEnd);
 }
 
+void SearchResults::showSelectedEntry()
+{
+	QList<QTableWidgetSelectionRange> ranges = table->selectedRanges();
+	if (ranges.count() == 0)
+		return;
+	int row = ranges.first().topRow();
+	QTableWidgetItem* item = table->item(row, 0);
+	if (!item)
+		return;
+	showEntry(item);
+}
+
 PDFFindDialog::PDFFindDialog(PDFDocument *document)
 	: QDialog(document->widget())
 {
