@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -40,7 +40,6 @@
 #include <QScrollBar>
 #include <QRegion>
 #include <QVector>
-#include <QHash>
 #include <QList>
 #include <QStack>
 #include <QInputDialog>
@@ -48,7 +47,6 @@
 #include <QUrl>
 #include <QShortcut>
 #include <QFileSystemWatcher>
-#include <QDebug>
 #include <QToolTip>
 
 #include <math.h>
@@ -74,6 +72,12 @@ const int kScroll = 2;
 const int kSelectText = 3;
 const int kSelectImage = 4;
 
+// duration of highlighting in PDF view (might make configurable?)
+const int kPDFHighlightDuration = 2000;
+
+// mask of all modified keys we check against
+const int keyboardModifierMask = Qt::ShiftModifier | Qt::ControlModifier | Qt::AltModifier | Qt::MetaModifier;
+
 #pragma mark === PDFMagnifier ===
 
 const int kMagFactor = 2;
@@ -142,6 +146,7 @@ void PDFMagnifier::resizeEvent(QResizeEvent * /*event*/)
 QCursor *PDFWidget::magnifierCursor = NULL;
 QCursor *PDFWidget::zoomInCursor = NULL;
 QCursor *PDFWidget::zoomOutCursor = NULL;
+QCursor *PDFWidget::synctexCursor = NULL;
 
 PDFWidget::PDFWidget()
 	: QLabel()
@@ -183,6 +188,7 @@ PDFWidget::PDFWidget()
 		magnifierCursor = new QCursor(QPixmap(":/images/images/magnifiercursor.png"));
 		zoomInCursor = new QCursor(QPixmap(":/images/images/zoomincursor.png"));
 		zoomOutCursor = new QCursor(QPixmap(":/images/images/zoomoutcursor.png"));
+		synctexCursor = new QCursor(Qt::ArrowCursor);
 	}
 	
 	ctxZoomInAction = new QAction(tr("Zoom In"), this);
@@ -204,6 +210,9 @@ PDFWidget::PDFWidget()
 	shortcutLeft = new QShortcut(QKeySequence("Left"), this, SLOT(leftOrPrev()));
 	shortcutDown = new QShortcut(QKeySequence("Down"), this, SLOT(downOrNext()));
 	shortcutRight = new QShortcut(QKeySequence("Right"), this, SLOT(rightOrNext()));
+
+	highlightRemover.setSingleShot(true);
+	connect(&highlightRemover, SIGNAL(timeout()), this, SLOT(clearHighlight()));
 }
 
 PDFWidget::~PDFWidget()
@@ -305,6 +314,7 @@ static Qt::KeyboardModifiers mouseDownModifiers;
 void PDFWidget::mousePressEvent(QMouseEvent *event)
 {
 	clickedLink = NULL;
+	bool handled = false;
 	
 	if (event->button() != Qt::LeftButton) {
 		QWidget::mousePressEvent(event);
@@ -312,35 +322,55 @@ void PDFWidget::mousePressEvent(QMouseEvent *event)
 	}
 
 	mouseDownModifiers = event->modifiers();
-	if (mouseDownModifiers & Qt::ControlModifier) {
+
+	// Modified behavior takes highest priority
+	if (!handled && (mouseDownModifiers & keyboardModifierMask) == Qt::ControlModifier) {
 		// ctrl key - this is a sync click, don't handle the mouseDown here
+		handled = true;
 	}
-	else {
-		// check for click in link
+	if (!handled && (mouseDownModifiers & keyboardModifierMask) == Qt::ShiftModifier) {
+		if(currentTool == kMagnifier) {
+			// do nothing - zoom in on mouseUp
+			handled = true;
+		}
+	}
+	if (!handled && (mouseDownModifiers & keyboardModifierMask) == Qt::AltModifier) {
+		if(currentTool == kMagnifier) {
+			// do nothing - zoom out on mouseUp
+			handled = true;
+		}
+	}
+	
+	// Context-specific behavior comes second
+	if (!handled && page) {
 		foreach (Poppler::Link* link, page->links()) {
 			// poppler's linkArea is relative to the page rect, it seems
 			QPointF scaledPos(event->pos().x() / scaleFactor / dpi * 72.0 / page->pageSizeF().width(),
 								event->pos().y() / scaleFactor / dpi * 72.0 / page->pageSizeF().height());
 			if (link->linkArea().contains(scaledPos)) {
 				clickedLink = link;
+				// opening the link is handled in mouseReleaseEvent
+				handled = true;
 				break;
 			}
 		}
-		if (clickedLink == NULL) {
-			switch (currentTool) {
-				case kMagnifier:
-					if (mouseDownModifiers & (Qt::ShiftModifier | Qt::AltModifier))
-						; // do nothing - zoom in or out (on mouseUp)
-					else
-						useMagnifier(event);
-					break;
-				
-				case kScroll:
-					setCursor(Qt::ClosedHandCursor);
-					scrollClickPos = event->globalPos();
-					usingTool = kScroll;
-					break;
-			}
+	}
+	
+	// Default behavior has the lowest priority
+	if (!handled) {
+		switch (currentTool) {
+			case kMagnifier:
+				useMagnifier(event);
+				break;
+		
+			case kScroll:
+				setCursor(Qt::ClosedHandCursor);
+				scrollClickPos = event->globalPos();
+				usingTool = kScroll;
+				break;
+			
+			default:
+				break;
 		}
 	}
 	event->accept();
@@ -348,38 +378,53 @@ void PDFWidget::mousePressEvent(QMouseEvent *event)
 
 void PDFWidget::mouseReleaseEvent(QMouseEvent *event)
 {
-	if (clickedLink != NULL) {
-		QPointF scaledPos(event->pos().x() / scaleFactor / dpi * 72.0 / page->pageSizeF().width(),
-							event->pos().y() / scaleFactor / dpi * 72.0 / page->pageSizeF().height());
-		if (clickedLink->linkArea().contains(scaledPos)) {
-			doLink(clickedLink);
-		}
-	}
-	else {
-		switch (usingTool) {
-			case kNone:
+	switch (usingTool) {
+		case kMagnifier:
+			// Ensure we stop using the tool before hiding the magnifier.
+			// Otherwise other events in the queue may be processed between
+			// "close()" and "usingTool=" that could show the magnifier
+			// again
+			usingTool = kNone;
+			magnifier->close();
+			break;
+		
+		default:
+			Qt::KeyboardModifiers mods = event->modifiers();
+			// Modified behavior takes highest priority
+			if((mods & keyboardModifierMask) == Qt::ControlModifier) {
 				// Ctrl-click to sync
-				if (mouseDownModifiers & Qt::ControlModifier) {
-					if (event->modifiers() & Qt::ControlModifier) {
-						QPointF pagePos(event->pos().x() / scaleFactor * 72.0 / dpi,
-										event->pos().y() / scaleFactor * 72.0 / dpi);
-						emit syncClick(pageIndex, pagePos);
-					}
+				if ((mouseDownModifiers & keyboardModifierMask) == Qt::ControlModifier) {
+					QPointF pagePos(event->pos().x() / scaleFactor * 72.0 / dpi,
+									event->pos().y() / scaleFactor * 72.0 / dpi);
+					emit syncClick(pageIndex, pagePos);
+				}
+				break;
+			}
+			if ((mods & keyboardModifierMask) == Qt::ShiftModifier) {
+				if (currentTool == kMagnifier) {
+					doZoom(event->pos(), 1);
 					break;
 				}
-				// check whether to zoom
+			}
+			if ((mods & keyboardModifierMask) == Qt::AltModifier) {
 				if (currentTool == kMagnifier) {
-					Qt::KeyboardModifiers mods = QApplication::keyboardModifiers();
-					if (mods & Qt::AltModifier)
-						doZoom(event->pos(), -1);
-					else if (mods & Qt::ShiftModifier)
-						doZoom(event->pos(), 1);
+					doZoom(event->pos(), -1);
+					break;
 				}
-				break;
-			case kMagnifier:
-				magnifier->close();
-				break;
-		}
+			}
+
+			// Context-specific behavior comes second
+			if (clickedLink != NULL) {
+				QPointF scaledPos(event->pos().x() / scaleFactor / dpi * 72.0 / page->pageSizeF().width(),
+									event->pos().y() / scaleFactor / dpi * 72.0 / page->pageSizeF().height());
+				if (clickedLink->linkArea().contains(scaledPos)) {
+					doLink(clickedLink);
+					break;
+				}
+			}
+
+			// Default behavior has the lowest priority
+			break;
 	}
 	clickedLink = NULL;
 	usingTool = kNone;
@@ -435,7 +480,15 @@ void PDFWidget::doLink(const Poppler::Link *link)
 			{
 				const Poppler::LinkBrowse *browse = dynamic_cast<const Poppler::LinkBrowse*>(link);
 				Q_ASSERT(browse != NULL);
-				TWApp::instance()->openUrl(QUrl::fromEncoded(browse->url().toAscii()));
+				QUrl url = QUrl::fromEncoded(browse->url().toAscii());
+				if (url.scheme() == "file") {
+					PDFDocument *doc = qobject_cast<PDFDocument*>(window());
+					if (doc) {
+						QFileInfo fi(QFileInfo(doc->fileName()).canonicalPath(), url.toLocalFile());
+						url = QUrl::fromLocalFile(fi.canonicalFilePath());
+					}
+				}
+				TWApp::instance()->openUrl(url);
 			}
 			break;
 // unsupported link types:
@@ -610,24 +663,69 @@ void PDFWidget::setTool(int tool)
 }
 
 void PDFWidget::updateCursor()
+{
+	updateCursor(mapFromGlobal(QCursor::pos()));
+}
+
+void PDFWidget::updateCursor(const QPoint& pos)
 {
 	if (usingTool != kNone)
 		return;
 
+	// Modified behavior takes highest priority
+	Qt::KeyboardModifiers mods = QApplication::keyboardModifiers();
+
+	if((mods & keyboardModifierMask) == Qt::ControlModifier) {
+		setCursor(*synctexCursor);
+		return;
+	}
+	if((mods & keyboardModifierMask) == Qt::AltModifier) {
+		if(currentTool == kMagnifier) {
+			setCursor(*zoomOutCursor);
+			return;
+		}
+	}
+	if((mods & keyboardModifierMask) == Qt::ShiftModifier) {
+		if(currentTool == kMagnifier) {
+			setCursor(*zoomInCursor);
+			return;
+		}
+	}
+	
+	// Context-specific behavior comes second
+	if(page) {
+		// check for link
+		foreach (Poppler::Link* link, page->links()) {
+			// poppler's linkArea is relative to the page rect
+			QPointF scaledPos(pos.x() / scaleFactor / dpi * 72.0 / page->pageSizeF().width(),
+								pos.y() / scaleFactor / dpi * 72.0 / page->pageSizeF().height());
+			if (link->linkArea().contains(scaledPos)) {
+				setCursor(Qt::PointingHandCursor);
+				if (link->linkType() == Poppler::Link::Browse) {
+					QPoint globalPos = mapToGlobal(pos);
+					const Poppler::LinkBrowse *browse = dynamic_cast<const Poppler::LinkBrowse*>(link);
+					Q_ASSERT(browse != NULL);
+					QRectF r = link->linkArea();
+					r.setWidth(r.width() * scaleFactor * dpi / 72.0 * page->pageSizeF().width());
+					r.setHeight(r.height() * scaleFactor * dpi / 72.0 * page->pageSizeF().height());
+					r.moveLeft(r.left() * scaleFactor * dpi / 72.0 * page->pageSizeF().width());
+					r.moveTop(r.top() * scaleFactor * dpi / 72.0 * page->pageSizeF().height());
+					QRect rr = r.toRect().normalized();
+					rr.setTopLeft(mapToGlobal(rr.topLeft()));
+					QToolTip::showText(globalPos, browse->url(), this, rr);
+				}
+				return;
+			}
+		}
+	}
+
+	// Default behavior has the lowest priority
 	switch (currentTool) {
 		case kScroll:
 			setCursor(Qt::OpenHandCursor);
 			break;
 		case kMagnifier:
-			{
-				Qt::KeyboardModifiers mods = QApplication::keyboardModifiers();
-				if (mods & Qt::AltModifier)
-					setCursor(*zoomOutCursor);
-				else if (mods & Qt::ShiftModifier)
-					setCursor(*zoomInCursor);
-				else
-					setCursor(*magnifierCursor);
-			}
+			setCursor(*magnifierCursor);
 			break;
 		case kSelectText:
 			setCursor(Qt::IBeamCursor);
@@ -635,37 +733,12 @@ void PDFWidget::updateCursor()
 		case kSelectImage:
 			setCursor(Qt::CrossCursor);
 			break;
+		default:
+			setCursor(Qt::ArrowCursor);
+			break;
 	}
 }
 
-void PDFWidget::updateCursor(const QPoint& pos)
-{
-	// check for link
-	foreach (Poppler::Link* link, page->links()) {
-		// poppler's linkArea is relative to the page rect
-		QPointF scaledPos(pos.x() / scaleFactor / dpi * 72.0 / page->pageSizeF().width(),
-							pos.y() / scaleFactor / dpi * 72.0 / page->pageSizeF().height());
-		if (link->linkArea().contains(scaledPos)) {
-			setCursor(Qt::PointingHandCursor);
-			if (link->linkType() == Poppler::Link::Browse) {
-				QPoint globalPos = mapToGlobal(pos);
-				const Poppler::LinkBrowse *browse = dynamic_cast<const Poppler::LinkBrowse*>(link);
-				Q_ASSERT(browse != NULL);
-				QRectF r = link->linkArea();
-				r.setWidth(r.width() * scaleFactor * dpi / 72.0 * page->pageSizeF().width());
-				r.setHeight(r.height() * scaleFactor * dpi / 72.0 * page->pageSizeF().height());
-				r.moveLeft(r.left() * scaleFactor * dpi / 72.0 * page->pageSizeF().width());
-				r.moveTop(r.top() * scaleFactor * dpi / 72.0 * page->pageSizeF().height());
-				QRect rr = r.toRect().normalized();
-				rr.setTopLeft(mapToGlobal(rr.topLeft()));
-				QToolTip::showText(globalPos, browse->url(), this, rr);
-			}
-			return;
-		}
-	}
-	updateCursor();
-}
-
 void PDFWidget::adjustSize()
 {
 	if (page) {
@@ -692,6 +765,7 @@ void PDFWidget::setResolution(int res)
 
 void PDFWidget::setHighlightPath(const QPainterPath& path)
 {
+	highlightRemover.stop();
 	highlightPath = path;
 	if (!path.isEmpty()) {
 		QScrollArea*	scrollArea = getScrollArea();
@@ -700,9 +774,17 @@ void PDFWidget::setHighlightPath(const QPainterPath& path)
 			scrollArea->ensureVisible((int)((r.left() + r.right()) / 2 * dpi / 72 * scaleFactor),
 										(int)((r.top() + r.bottom()) / 2 * dpi / 72 * scaleFactor));
 		}
+		if (kPDFHighlightDuration > 0)
+			highlightRemover.start(kPDFHighlightDuration);
 	}
 }
 
+void PDFWidget::clearHighlight()
+{
+	highlightPath = QPainterPath();
+	update();
+}
+
 void PDFWidget::reloadPage()
 {
 	if (page != NULL)
@@ -1018,18 +1100,27 @@ QScrollArea* PDFWidget::getScrollArea()
 QList<PDFDocument*> PDFDocument::docList;
 
 PDFDocument::PDFDocument(const QString &fileName, TeXDocument *texDoc)
-	: watcher(NULL), reloadTimer(NULL), scanner(NULL)
+	: watcher(NULL), reloadTimer(NULL), scanner(NULL), openedManually(false)
 {
 	init();
 
 	if (texDoc == NULL) {
-		TWApp::instance()->addToRecentFiles(fileName);
+		openedManually = true;
 		watcher = new QFileSystemWatcher(this);
 		connect(watcher, SIGNAL(fileChanged(const QString&)), this, SLOT(reloadWhenIdle()));
 	}
 
 	loadFile(fileName);
 
+	QMap<QString,QVariant> properties = TWApp::instance()->getFileProperties(curFile);
+	if (properties.contains("geometry"))
+		restoreGeometry(properties.value("geometry").toByteArray());
+	else
+		TWUtils::zoomToHalfScreen(this, true);
+
+	if (properties.contains("state"))
+		restoreState(properties.value("state").toByteArray(), kPDFWindowStateVersion);
+	
 	if (texDoc != NULL) {
 		stackUnder((QWidget*)texDoc);
 		actionSide_by_Side->setEnabled(true);
@@ -1100,6 +1191,7 @@ PDFDocument::init()
 	connect(actionNew, SIGNAL(triggered()), qApp, SLOT(newFile()));
 	connect(actionNew_from_Template, SIGNAL(triggered()), qApp, SLOT(newFromTemplate()));
 	connect(actionOpen, SIGNAL(triggered()), qApp, SLOT(open()));
+	connect(actionPrintPdf, SIGNAL(triggered()), this, SLOT(print()));
 
 	connect(actionQuit_TeXworks, SIGNAL(triggered()), TWApp::instance(), SLOT(maybeQuit()));
 
@@ -1151,7 +1243,7 @@ PDFDocument::init()
 
 	connect(this, SIGNAL(destroyed()), qApp, SLOT(updateWindowMenus()));
 
-	connect(qApp, SIGNAL(syncPdf(const QString&, int)), this, SLOT(syncFromSource(const QString&, int)));
+	connect(qApp, SIGNAL(syncPdf(const QString&, int, bool)), this, SLOT(syncFromSource(const QString&, int, bool)));
 
 	menuShow->addAction(toolBar->toggleViewAction());
 	menuShow->addSeparator();
@@ -1182,9 +1274,12 @@ PDFDocument::init()
 	QSETTINGS_OBJECT(settings);
 	TWUtils::applyToolbarOptions(this, settings.value("toolBarIconSize", 2).toInt(), settings.value("toolBarShowText", false).toBool());
 
-	TWUtils::insertHelpMenuItems(menuHelp);
+	TWApp::instance()->updateWindowMenus();
 	
-	TWUtils::zoomToHalfScreen(this, true);
+	initScriptable(menuScripts, actionAbout_Scripts, actionManage_Scripts,
+				   actionUpdate_Scripts, actionShow_Scripts_Folder);
+	
+	TWUtils::insertHelpMenuItems(menuHelp);
 	TWUtils::installCustomShortcuts(this);
 }
 
@@ -1233,16 +1328,6 @@ void PDFDocument::updateWindowMenu()
 	TWUtils::updateWindowMenu(this, menuWindow);
 }
 
-void PDFDocument::selectWindow(bool activate)
-{
-	show();
-	raise();
-	if (activate)
-		activateWindow();
-	if (isMinimized())
-		showNormal();
-}
-
 void PDFDocument::sideBySide()
 {
 	if (sourceDocList.count() > 0) {
@@ -1254,44 +1339,6 @@ void PDFDocument::sideBySide()
 		placeOnRight();
 }
 
-void PDFDocument::placeOnLeft()
-{
-	TWUtils::zoomToHalfScreen(this, false);
-}
-
-void PDFDocument::placeOnRight()
-{
-	TWUtils::zoomToHalfScreen(this, true);
-}
-
-void PDFDocument::hideFloatersUnlessThis(QWidget* currWindow)
-{
-	PDFDocument* p = qobject_cast<PDFDocument*>(currWindow);
-	if (p == this)
-		return;
-	foreach (QObject* child, children()) {
-		QToolBar* tb = qobject_cast<QToolBar*>(child);
-		if (tb && tb->isVisible() && tb->isFloating()) {
-			latentVisibleWidgets.append(tb);
-			tb->hide();
-			continue;
-		}
-		QDockWidget* dw = qobject_cast<QDockWidget*>(child);
-		if (dw && dw->isVisible() && dw->isFloating()) {
-			latentVisibleWidgets.append(dw);
-			dw->hide();
-			continue;
-		}
-	}
-}
-
-void PDFDocument::showFloaters()
-{
-	foreach (QWidget* w, latentVisibleWidgets)
-		w->show();
-	latentVisibleWidgets.clear();
-}
-
 bool PDFDocument::event(QEvent *event)
 {
 	switch (event->type()) {
@@ -1308,9 +1355,21 @@ bool PDFDocument::event(QEvent *event)
 void PDFDocument::closeEvent(QCloseEvent *event)
 {
 	event->accept();
+	if (openedManually) {
+		saveRecentFileInfo();
+	}
 	deleteLater();
 }
 
+void PDFDocument::saveRecentFileInfo()
+{
+	QMap<QString,QVariant> fileProperties;
+	fileProperties.insert("path", curFile);
+	fileProperties.insert("geometry", saveGeometry());
+	fileProperties.insert("state", saveState(kPDFWindowStateVersion));
+	TWApp::instance()->addToRecentFiles(fileProperties);
+}
+
 void PDFDocument::loadFile(const QString &fileName)
 {
 	setCurrentFile(fileName);
@@ -1407,7 +1466,7 @@ void PDFDocument::syncClick(int pageIndex, const QPointF& pos)
 	}
 }
 
-void PDFDocument::syncFromSource(const QString& sourceFile, int lineNo)
+void PDFDocument::syncFromSource(const QString& sourceFile, int lineNo, bool activatePreview)
 {
 	if (scanner == NULL)
 		return;
@@ -1449,7 +1508,8 @@ void PDFDocument::syncFromSource(const QString& sourceFile, int lineNo)
 			path.setFillRule(Qt::WindingFill);
 			pdfWidget->setHighlightPath(path);
 			pdfWidget->update();
-			selectWindow();
+			if (activatePreview)
+				selectWindow();
 		}
 	}
 }
@@ -1584,12 +1644,14 @@ void PDFDocument::updateTypesettingAction(bool processRunning)
 	if (processRunning) {
 		disconnect(actionTypeset, SIGNAL(triggered()), this, SLOT(retypeset()));
 		actionTypeset->setIcon(QIcon(":/images/tango/process-stop.png"));
+		actionTypeset->setText(tr("Abort typesetting"));
 		connect(actionTypeset, SIGNAL(triggered()), this, SLOT(interrupt()));
 		enableTypesetAction(true);
 	}
 	else {
 		disconnect(actionTypeset, SIGNAL(triggered()), this, SLOT(interrupt()));
 		actionTypeset->setIcon(QIcon(":/images/images/runtool.png"));
+		actionTypeset->setText(tr("Typeset"));
 		connect(actionTypeset, SIGNAL(triggered()), this, SLOT(retypeset()));
 	}
 }
@@ -1622,7 +1684,7 @@ void PDFDocument::dropEvent(QDropEvent *event)
 		const QList<QUrl> urls = event->mimeData()->urls();
 		foreach (const QUrl& url, urls)
 			if (url.scheme() == "file")
-				TWApp::instance()->open(url.toLocalFile());
+				TWApp::instance()->openFile(url.toLocalFile());
 		event->acceptProposedAction();
 	}
 }
@@ -1633,7 +1695,7 @@ void PDFDocument::doFindDialog()
 		doFindAgain(true);
 }
 
-void PDFDocument::doFindAgain(bool newSearch /*= false*/)
+void PDFDocument::doFindAgain(bool newSearch /* = false */)
 {
 	QSETTINGS_OBJECT(settings);
 	int pageIdx;
@@ -1710,3 +1772,19 @@ void PDFDocument::doFindAgain(bool newSearch /*= false*/)
 	}
 }
 
+void PDFDocument::print()
+{
+	// Currently, printing is not supported in a reliable, cross-platform way
+	// Instead, offer to open the document in the system's default viewer
+	
+	QString msg = tr("Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.\n").arg(TEXWORKS_NAME);
+	msg += tr("Do you want to open the file in the default viewer for printing instead?");
+	msg += tr(" (remember to close it again to avoid access problems)");
+	
+	if(QMessageBox::information(this,
+		tr("Print Pdf..."), msg,
+		QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes) == QMessageBox::Yes
+	) {
+		QDesktopServices::openUrl(QUrl::fromLocalFile(curFile));
+	}
+}
