@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -32,7 +32,8 @@
 #include <QMainWindow>
 #include <QToolBar>
 #include <QDesktopWidget>
-#include <QtAlgorithms>
+//#include <QtAlgorithms>
+#include <QMessageBox>
 
 PrefsDialog::PrefsDialog(QWidget *parent)
 	: QDialog(parent)
@@ -86,6 +87,10 @@ void PrefsDialog::changedTabPanel(int index)
 		case 3: // Typesetting
 			binPathList->setFocus();
 			break;
+		case 4: // Script
+			if (page->focusWidget() != NULL)
+				page->focusWidget()->clearFocus();
+			break;
 	}
 }
 
@@ -257,17 +262,6 @@ void PrefsDialog::buttonClicked(QAbstractButton *whichButton)
 		restoreDefaults();
 }
 
-const int kDefault_LaunchOption = 1;
-const int kDefault_ToolBarIcons = 2;
-const bool kDefault_ToolBarText = false;
-const int kDefault_SyntaxColoring = 0;
-const int kDefault_IndentMode = -1;
-const bool kDefault_LineNumbers = false;
-const bool kDefault_WrapLines = true;
-const int kDefault_TabWidth = 32;
-const bool kDefault_HideConsole = true;
-const bool kDefault_HighlightCurrentLine = true;
-
 void PrefsDialog::restoreDefaults()
 {
 	switch (tabWidget->currentIndex()) {
@@ -311,6 +305,7 @@ void PrefsDialog::restoreDefaults()
 			wrapLines->setChecked(kDefault_WrapLines);
 			syntaxColoring->setCurrentIndex(kDefault_SyntaxColoring);
 			autoIndent->setCurrentIndex(kDefault_IndentMode);
+			smartQuotes->setCurrentIndex(kDefault_QuotesMode);
 			encoding->setCurrentIndex(encoding->findText("UTF-8"));
 			highlightCurrentLine->setChecked(kDefault_HighlightCurrentLine);
 			break;
@@ -357,6 +352,12 @@ void PrefsDialog::restoreDefaults()
 			pathsChanged = true;
 			toolsChanged = true;
 			break;
+
+		case 4:
+			// Scripts
+			allowSystemCommands->setChecked(false);
+			scriptDebugger->setChecked(false);
+			break;
 	}
 }
 
@@ -364,7 +365,7 @@ void PrefsDialog::initPathAndToolLists()
 {
 	binPathList->clear();
 	toolList->clear();
-	binPathList->addItems(TWApp::instance()->getBinaryPaths());
+	binPathList->addItems(TWApp::instance()->getPrefsBinaryPaths());
 	engineList = TWApp::instance()->getEngineList();
 	foreach (Engine e, engineList) {
 		toolList->addItem(e.name());
@@ -382,7 +383,14 @@ void PrefsDialog::initPathAndToolLists()
 
 const int kSystemLocaleIndex = 0;
 const int kEnglishLocaleIndex = 1;
-const int kFirstTranslationIndex = 2;
+const int kFirstTranslationIndex = 1;
+
+typedef QPair<QString, QString> DictPair;
+
+static bool dictPairLessThan(const DictPair& d1, const DictPair& d2)
+{
+	return d1.first.toLower() < d2.first.toLower();
+}
 
 QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 {
@@ -399,8 +407,35 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	QStringList indentModes = CompletingEdit::autoIndentModes();
 	dlg.autoIndent->addItems(indentModes);
 	
-	dlg.language->addItems(*TWUtils::getDictionaryList());
-	
+	QStringList quotesModes = CompletingEdit::smartQuotesModes();
+	dlg.smartQuotes->addItems(quotesModes);
+
+	QList< DictPair > dictList;
+	foreach (const QString& dictKey, TWUtils::getDictionaryList()->uniqueKeys()) {
+		QString dict, label;
+		QLocale loc;
+
+		foreach (dict, TWUtils::getDictionaryList()->values(dictKey)) {
+			loc = QLocale(dict);
+			if (loc.language() != QLocale::C) break;
+		}
+
+		if (loc.language() == QLocale::C)
+			label = dict;
+		else {
+			label = QLocale::languageToString(loc.language());
+			QLocale::Country country = loc.country();
+			if (country != QLocale::AnyCountry)
+				label += " - " + QLocale::countryToString(country);
+			label += " (" + dict + ")";
+		}
+
+		dictList << qMakePair(label, dict);
+	}
+	qSort(dictList.begin(), dictList.end(), dictPairLessThan);
+	foreach (const DictPair& dict, dictList)
+		dlg.language->addItem(dict.first, dict.second);
+		
 	QSETTINGS_OBJECT(settings);
 	// initialize controls based on the current settings
 	
@@ -435,7 +470,6 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	QString oldLocale = settings.value("locale").toString();
 	// System and English are predefined at index 0 and 1 (see constants above)
 	dlg.localePopup->addItem(tr("System default [%1]").arg(QLocale::languageToString(QLocale(QLocale::system().name()).language())));
-	dlg.localePopup->addItem("English");	// we don't localize locale names for now
 	int oldLocaleIndex = oldLocale.isEmpty() ? kSystemLocaleIndex : kEnglishLocaleIndex;
 	QStringList *trList = TWUtils::getTranslationList();
 	QStringList::ConstIterator iter;
@@ -466,6 +500,9 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	dlg.autoIndent->setCurrentIndex(settings.contains("autoIndent")
 							? 1 + indentModes.indexOf(settings.value("autoIndent").toString())
 							: 1 + kDefault_IndentMode);
+	dlg.smartQuotes->setCurrentIndex(settings.contains("smartQuotes")
+							? 1 + quotesModes.indexOf(settings.value("smartQuotes").toString())
+							: 1 + kDefault_QuotesMode);
 	dlg.lineNumbers->setChecked(settings.value("lineNumbers", kDefault_LineNumbers).toBool());
 	dlg.wrapLines->setChecked(settings.value("wrapLines", kDefault_WrapLines).toBool());
 	dlg.tabWidth->setValue(settings.value("tabWidth", kDefault_TabWidth).toInt());
@@ -480,8 +517,8 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	dlg.encoding->setCurrentIndex(nameList.indexOf(TWApp::instance()->getDefaultCodec()->name()));
 	dlg.highlightCurrentLine->setChecked(settings.value("highlightCurrentLine", kDefault_HighlightCurrentLine).toBool());
 
-	QString defLang = settings.value("language", tr("None")).toString();
-	int i = dlg.language->findText(settings.value("language", tr("None")).toString());
+	QString defDict = settings.value("language", "None").toString();
+	int i = dlg.language->findData(defDict);
 	if (i >= 0)
 		dlg.language->setCurrentIndex(i);
 
@@ -524,6 +561,19 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 	dlg.initPathAndToolLists();
 	dlg.autoHideOutput->setChecked(settings.value("autoHideConsole", kDefault_HideConsole).toBool());
 
+	// Scripts
+	dlg.allowScriptFileReading->setChecked(settings.value("allowScriptFileReading", false).toBool());
+	dlg.allowScriptFileWriting->setChecked(settings.value("allowScriptFileWriting", false).toBool());
+	dlg.allowSystemCommands->setChecked(settings.value("allowSystemCommands", false).toBool());
+	dlg.enableScriptingPlugins->setChecked(settings.value("enableScriptingPlugins", false).toBool());
+	// there is always at least JSScriptInterface
+	if (TWApp::instance()->getScriptManager()->languages().size() <= 1)
+		dlg.enableScriptingPlugins->setEnabled(false);
+	dlg.scriptDebugger->setChecked(settings.value("scriptDebugger", false).toBool());
+#if QT_VERSION < 0x040500
+	dlg.scriptDebugger->setEnabled(false);
+#endif
+	
 	// Decide which tab to select initially
 	if (sCurrentTab == -1) {
 		if (parent && parent->inherits("TeXDocument"))
@@ -576,10 +626,6 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 						settings.remove("locale");
 					}
 					break;
-				case kEnglishLocaleIndex: // built-in English
-					TWApp::instance()->applyTranslation(QString());
-					settings.setValue("locale", "en");
-					break;
 				default:
 					{
 						QString locale = trList->at(dlg.localePopup->currentIndex() - kFirstTranslationIndex);
@@ -593,6 +639,7 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 		// Editor
 		settings.setValue("syntaxColoring", dlg.syntaxColoring->currentText());
 		settings.setValue("autoIndent", dlg.autoIndent->currentText());
+		settings.setValue("smartQuotes", dlg.smartQuotes->currentText());
 		settings.setValue("lineNumbers", dlg.lineNumbers->isChecked());
 		settings.setValue("wrapLines", dlg.wrapLines->isChecked());
 		settings.setValue("tabWidth", dlg.tabWidth->value());
@@ -600,11 +647,27 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 		font.setPointSize(dlg.fontSize->value());
 		settings.setValue("font", font.toString());
 		TWApp::instance()->setDefaultCodec(QTextCodec::codecForName(dlg.encoding->currentText().toAscii()));
-		settings.setValue("language", dlg.language->currentText());
+		if (dlg.language->currentIndex() >= 0) {
+			QVariant data = dlg.language->itemData(dlg.language->currentIndex());
+			if (data.isValid())
+				settings.setValue("language", data);
+			else
+				settings.setValue("language", "None");
+		}
+		else
+			settings.setValue("language", "None");
 		bool highlightLine = dlg.highlightCurrentLine->isChecked();
 		settings.setValue("highlightCurrentLine", highlightLine);
 		CompletingEdit::setHighlightCurrentLine(highlightLine);
 		
+		// Since the tab width can't be set by any other means, forcibly update
+		// all windows now
+		foreach (QWidget* widget, TWApp::instance()->allWidgets()) {
+			QTextEdit* editor = qobject_cast<QTextEdit*>(widget);
+			if (editor)
+			    editor->setTabStopWidth(dlg.tabWidth->value());
+		}
+		
 		// Preview
 		int scaleOption = 1;
 		if (dlg.fitWidth->isChecked())
@@ -654,6 +717,16 @@ QDialog::DialogCode PrefsDialog::doPrefsDialog(QWidget *parent)
 			TWApp::instance()->setEngineList(dlg.engineList);
 		TWApp::instance()->setDefaultEngine(dlg.defaultTool->currentText());
 		settings.setValue("autoHideConsole", dlg.autoHideOutput->isChecked());
+
+		// Scripts
+		settings.setValue("allowScriptFileReading", dlg.allowScriptFileReading->isChecked());
+		settings.setValue("allowScriptFileWriting", dlg.allowScriptFileWriting->isChecked());
+		settings.setValue("allowSystemCommands", dlg.allowSystemCommands->isChecked());
+		settings.setValue("enableScriptingPlugins", dlg.enableScriptingPlugins->isChecked());
+		settings.setValue("scriptDebugger", dlg.scriptDebugger->isChecked());
+		// with changed settings, the availability of scripts may have changed
+		// (e.g., because of enabling/disabling the use of scripting plugins)
+		TWApp::instance()->updateScriptsList();
 	}
 
 	return result;
@@ -666,7 +739,7 @@ ToolConfig::ToolConfig(QWidget *parent)
 {
 	init();
 }
-	
+
 void ToolConfig::init()
 {
 	setupUi(this);
@@ -676,6 +749,23 @@ void ToolConfig::init()
 	connect(argDown, SIGNAL(clicked()), this, SLOT(moveArgDown()));
 	connect(argAdd, SIGNAL(clicked()), this, SLOT(addArg()));
 	connect(argRemove, SIGNAL(clicked()), this, SLOT(removeArg()));
+	connect(btnBrowseForProgram, SIGNAL(clicked()), this, SLOT(browseForProgram()));
+}
+
+void ToolConfig::browseForProgram()
+{
+	QFileInfo info(program->text());
+	QString str = QFileDialog::getOpenFileName(this, tr("Select program file"),
+											   info.exists() ? info.canonicalFilePath() : QString());
+	if (!str.isNull()) {
+		info.setFile(str);
+		if (!info.isExecutable()) {
+			QMessageBox::warning(this, tr("Invalid program"),
+								 tr("The file '%1' is not executable!").arg(info.fileName()));
+			return;
+		}
+		program->setText(info.canonicalFilePath());
+	}
 }
 
 void ToolConfig::updateArgButtons()
