@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,6 +25,7 @@
 #include "PDFDocument.h"
 #include "PrefsDialog.h"
 #include "TemplateDialog.h"
+#include "TWSystemCmd.h"
 
 #include "TWVersion.h"
 #include "SvnRev.h"
@@ -51,30 +52,38 @@
 #include <QUrl>
 #include <QDesktopServices>
 
-#ifdef Q_WS_WIN
-#include <QtPlugin>
-Q_IMPORT_PLUGIN(qjpeg)
-#endif
-
 #if defined(HAVE_POPPLER_XPDF_HEADERS) && (defined(Q_WS_MAC) || defined(Q_WS_WIN))
 #include "poppler-config.h"
 #include "GlobalParams.h"
 #endif
 
+#ifdef Q_WS_MAC
+#include <CoreServices/CoreServices.h>
+#endif
+
+#ifdef Q_WS_WIN
+#include <windows.h>
+#ifndef VER_SUITE_WH_SERVER /* not defined in my mingw system */
+#define VER_SUITE_WH_SERVER 0x00008000
+#endif
+#endif
+
 #define SETUP_FILE_NAME "texworks-setup.ini"
 
-const int kDefaultMaxRecentFiles = 10;
+#define DEFAULT_ENGINE_NAME "pdfLaTeX"
+
+const int kDefaultMaxRecentFiles = 20;
 
 TWApp *TWApp::theAppInstance = NULL;
 
 TWApp::TWApp(int &argc, char **argv)
-	: QApplication(argc, argv)
+	: ConfigurableApp(argc, argv)
 	, defaultCodec(NULL)
 	, binaryPaths(NULL)
 	, defaultBinPaths(NULL)
 	, engineList(NULL)
 	, defaultEngineIndex(0)
-	, settingsFormat(QSettings::NativeFormat)
+	, scriptManager(NULL)
 #ifdef Q_WS_WIN
 	, messageTargetWindow(NULL)
 #endif
@@ -82,6 +91,14 @@ TWApp::TWApp(int &argc, char **argv)
 	init();
 }
 
+TWApp::~TWApp()
+{
+	if (scriptManager) {
+		scriptManager->saveDisabledList();
+		delete scriptManager;
+	}
+}
+
 void TWApp::init()
 {
 	setWindowIcon(QIcon(":/images/images/TeXworks.png"));
@@ -141,6 +158,9 @@ void TWApp::init()
 	if (popplerDataDir.exists()) {
 		globalParams = new GlobalParams(popplerDataDir.canonicalPath().toUtf8().data());
 	}
+	else {
+		globalParams = new GlobalParams();
+	}
 #endif
 
 	// Required for TWUtils::getLibraryPath()
@@ -160,6 +180,8 @@ void TWApp::init()
 
 	TWUtils::readConfig();
 
+	scriptManager = new TWScriptManager;
+
 #ifdef Q_WS_MAC
 	setQuitOnLastWindowClosed(false);
 
@@ -252,10 +274,10 @@ void TWApp::about()
 {
 	QString aboutText = tr("<p>%1 is a simple environment for editing, typesetting, and previewing TeX documents.</p>").arg(TEXWORKS_NAME);
 	aboutText += "<small>";
-	aboutText += "<p>&#xA9; 2007-2009 Jonathan Kew";
-	aboutText += tr("<br>Version %1 (r.%2)").arg(TEXWORKS_VERSION).arg(SVN_REVISION);
+	aboutText += "<p>&#xA9; 2007-2011  Jonathan Kew, Stefan L&#xF6;ffler";
+	aboutText += tr("<br>Version %1 r.%2 (%3)").arg(TEXWORKS_VERSION).arg(SVN_REVISION).arg(TW_BUILD_ID_STR);
 	aboutText += tr("<p>Distributed under the <a href=\"http://www.gnu.org/licenses/gpl-2.0.html\">GNU General Public License</a>, version 2.");
-	aboutText += tr("<p><a href=\"http://trolltech.com/products/\">Qt4</a> application framework by Qt Software, a division of Nokia Corporation.");
+	aboutText += tr("<p><a href=\"http://qt.nokia.com/\">Qt application framework</a> v%1 by Qt Software, a division of Nokia Corporation.").arg(qVersion());
 	aboutText += tr("<br><a href=\"http://poppler.freedesktop.org/\">Poppler</a> PDF rendering library by Kristian H&#xF8;gsberg, Albert Astals Cid and others.");
 	aboutText += tr("<br><a href=\"http://hunspell.sourceforge.net/\">Hunspell</a> spell checker by L&#xE1;szl&#xF3; N&#xE9;meth.");
 	aboutText += tr("<br>Concept and resources from <a href=\"http://www.uoregon.edu/~koch/texshop/\">TeXShop</a> by Richard Koch.");
@@ -281,13 +303,229 @@ void TWApp::goToHomePage()
 	openUrl(QUrl("http://texworks.org/"));
 }
 
+#ifdef Q_WS_WIN
+/* based on MSDN sample code from http://msdn.microsoft.com/en-us/library/ms724429(VS.85).aspx */
+typedef void (WINAPI *PGNSI)(LPSYSTEM_INFO);
+
+QString TWApp::GetWindowsVersionString()
+{
+	OSVERSIONINFOEXA osvi;
+	SYSTEM_INFO si;
+	PGNSI pGNSI;
+	BOOL bOsVersionInfoEx;
+	QString result("(unknown version)");
+	
+	memset(&si, 0, sizeof(SYSTEM_INFO));
+	memset(&osvi, 0, sizeof(OSVERSIONINFOEXA));
+	
+	osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEXA);
+	if ( !(bOsVersionInfoEx = GetVersionExA ((OSVERSIONINFOA *) &osvi)) )
+		return result;
+	
+	// Call GetNativeSystemInfo if supported or GetSystemInfo otherwise.
+	pGNSI = (PGNSI) GetProcAddress(GetModuleHandle(TEXT("kernel32.dll")), "GetNativeSystemInfo");
+	if (NULL != pGNSI)
+		pGNSI(&si);
+	else
+		GetSystemInfo(&si);
+	
+	if ( VER_PLATFORM_WIN32_NT == osvi.dwPlatformId && osvi.dwMajorVersion > 4 ) {
+		if ( osvi.dwMajorVersion == 6 ) {
+			if ( osvi.dwMinorVersion == 0 ) {
+				if ( osvi.wProductType == VER_NT_WORKSTATION )
+					result = "Vista";
+				else
+					result = "Server 2008";
+			}
+			else if ( osvi.dwMinorVersion == 1 ) {
+				if( osvi.wProductType == VER_NT_WORKSTATION )
+					result = "7";
+				else
+					result = "Server 2008 R2";
+			}
+		}
+		else if ( osvi.dwMajorVersion == 5 && osvi.dwMinorVersion == 2 ) {
+			if ( GetSystemMetrics(SM_SERVERR2) )
+				result = "Server 2003 R2";
+			else if ( osvi.wSuiteMask & VER_SUITE_STORAGE_SERVER )
+				result = "Storage Server 2003";
+			else if ( osvi.wSuiteMask & VER_SUITE_WH_SERVER )
+				result = "Home Server";
+			else if ( osvi.wProductType == VER_NT_WORKSTATION &&
+					si.wProcessorArchitecture==PROCESSOR_ARCHITECTURE_AMD64)
+				result = "XP Professional x64 Edition";
+			else
+				result = "Server 2003";
+		}
+		else if ( osvi.dwMajorVersion == 5 && osvi.dwMinorVersion == 1 ) {
+			result = "XP ";
+			if ( osvi.wSuiteMask & VER_SUITE_PERSONAL )
+				result += "Home Edition";
+			else
+				result += "Professional";
+		}
+		else if ( osvi.dwMajorVersion == 5 && osvi.dwMinorVersion == 0 ) {
+			result = "2000 ";
+			
+			if ( osvi.wProductType == VER_NT_WORKSTATION ) {
+				result += "Professional";
+			}
+			else {
+				if ( osvi.wSuiteMask & VER_SUITE_DATACENTER )
+					result += "Datacenter Server";
+				else if ( osvi.wSuiteMask & VER_SUITE_ENTERPRISE )
+					result += "Advanced Server";
+				else
+					result += "Server";
+			}
+		}
+		
+		if ( strlen(osvi.szCSDVersion) > 0 ) {
+			result += " ";
+			result += osvi.szCSDVersion;
+		}
+		
+		if ( osvi.dwMajorVersion >= 6 ) {
+			if ( si.wProcessorArchitecture==PROCESSOR_ARCHITECTURE_AMD64 )
+				result += ", 64-bit";
+			else if (si.wProcessorArchitecture==PROCESSOR_ARCHITECTURE_INTEL )
+				result += ", 32-bit";
+		}
+	}
+	
+	return result;
+}
+
+unsigned int TWApp::GetWindowsVersion()
+{
+	OSVERSIONINFOEXA osvi;
+	
+	memset(&osvi, 0, sizeof(OSVERSIONINFOEXA));
+	
+	osvi.dwOSVersionInfoSize = sizeof(OSVERSIONINFOEXA);
+	if ( !GetVersionExA ((OSVERSIONINFOA *) &osvi) )
+		return 0;
+	
+	return (osvi.dwMajorVersion << 24) | (osvi.dwMinorVersion << 16) | (osvi.wServicePackMajor << 8) | (osvi.wServicePackMinor << 0);
+}
+#endif
+
+const QStringList TWApp::getBinaryPaths(QStringList& systemEnvironment)
+{
+#ifdef Q_WS_WIN
+#define PATH_CASE_SENSITIVE	Qt::CaseInsensitive
+#else
+#define PATH_CASE_SENSITIVE	Qt::CaseSensitive
+#endif
+	QStringList binPaths = getPrefsBinaryPaths();
+	QMutableStringListIterator envIter(systemEnvironment);
+	while (envIter.hasNext()) {
+		QString& envVar = envIter.next();
+		if (envVar.startsWith("PATH=", PATH_CASE_SENSITIVE)) {
+			foreach (const QString& s, envVar.mid(5).split(QChar(PATH_LIST_SEP), QString::SkipEmptyParts)) {
+				if (!binPaths.contains(s)) {
+					binPaths.append(s);
+				}
+			}
+			envVar = envVar.left(5) + binPaths.join(QChar(PATH_LIST_SEP));
+			break;
+		}
+	}
+	return binPaths;
+}
+
+QString TWApp::findProgram(const QString& program, const QStringList& binPaths)
+{
+	QStringListIterator pathIter(binPaths);
+	bool found = false;
+	QFileInfo fileInfo;
+#ifdef Q_WS_WIN
+	QStringList executableTypes = QStringList() << "exe" << "com" << "cmd" << "bat";
+#endif
+	while (pathIter.hasNext() && !found) {
+		QString path = pathIter.next();
+		fileInfo = QFileInfo(path, program);
+		found = fileInfo.exists() && fileInfo.isExecutable();
+#ifdef Q_WS_WIN
+		// try adding common executable extensions, if one was not already present
+		if (!found && !executableTypes.contains(fileInfo.suffix())) {
+			QStringListIterator extensions(executableTypes);
+			while (extensions.hasNext() && !found) {
+				fileInfo = QFileInfo(path, program + "." + extensions.next());
+				found = fileInfo.exists() && fileInfo.isExecutable();
+			}
+		}
+#endif
+	}
+	return found ? fileInfo.absoluteFilePath() : QString();
+}
+
 void TWApp::writeToMailingList()
 {
-	openUrl(QUrl("mailto:texworks@tug.org?subject=message from TeXworks user"));
+	// The strings here are deliberately NOT localizable!
+	QString address("texworks@tug.org");
+	QString subject("Message from TeXworks user");
+	QString body("\n\n----- configuration info -----\n");
+
+	body += "TeXworks version : " TEXWORKS_VERSION "r" SVN_REVISION_STR " (" TW_BUILD_ID_STR ")\n";
+#ifdef Q_WS_MAC
+	body += "Install location : " + QDir(applicationDirPath() + "/../..").absolutePath() + "\n";
+#else
+	body += "Install location : " + applicationFilePath() + "\n";
+#endif
+	body += "Library path     : " + TWUtils::getLibraryPath(QString()) + "\n";
+
+	QStringList sysEnv(QProcess::systemEnvironment());
+	const QStringList binPaths = getBinaryPaths(sysEnv);
+	QString pdftex = findProgram("pdftex", binPaths);
+	if (pdftex.isEmpty())
+		pdftex = "not found";
+	else {
+		QFileInfo info(pdftex);
+		pdftex = info.canonicalFilePath();
+	}
+	
+	body += "pdfTeX location  : " + pdftex + "\n";
+	
+	body += "Operating system : ";
+#ifdef Q_WS_WIN
+	body += "Windows " + GetWindowsVersionString() + "\n";
+#else
+#ifdef Q_WS_MAC
+#define UNAME_CMDLINE "uname -v"
+#else
+#define UNAME_CMDLINE "uname -a"
+#endif
+	QString unameResult("unknown");
+	TWSystemCmd unameCmd(this, true);
+	unameCmd.setProcessChannelMode(QProcess::MergedChannels);
+	unameCmd.start(UNAME_CMDLINE);			
+	if (unameCmd.waitForStarted(1000) && unameCmd.waitForFinished(1000))
+		unameResult = unameCmd.getResult().trimmed();
+#ifdef Q_WS_MAC
+	SInt32 major = 0, minor = 0, bugfix = 0;
+	Gestalt(gestaltSystemVersionMajor, &major);
+	Gestalt(gestaltSystemVersionMinor, &minor);
+	Gestalt(gestaltSystemVersionBugFix, &bugfix);
+	body += QString("Mac OS X %1.%2.%3").arg(major).arg(minor).arg(bugfix);
+	body += " (" + unameResult + ")\n";
+#else
+	body += unameResult + "\n";
+#endif
+#endif
+
+	body += "Qt4 version      : " QT_VERSION_STR " (build) / ";
+	body += qVersion();
+	body += " (runtime)\n";
+	body += "------------------------------\n";
+
+	openUrl(QUrl(QString("mailto:%1?subject=%2&body=%3").arg(address).arg(subject).arg(body)));
 }
 
 void TWApp::launchAction()
 {
+	scriptManager->runHooks("TeXworksLaunched");
+
 	if (TeXDocument::documentList().size() > 0 || PDFDocument::documentList().size() > 0)
 		return;
 
@@ -325,6 +563,7 @@ void TWApp::newFile()
 	TeXDocument *doc = new TeXDocument;
 	doc->show();
 	doc->editor()->updateLineNumberAreaWidth(0);
+	doc->runHooks("NewFile");
 }
 
 void TWApp::newFromTemplate()
@@ -336,6 +575,7 @@ void TWApp::newFromTemplate()
 			doc->makeUntitled();
 			doc->selectWindow();
 			doc->editor()->updateLineNumberAreaWidth(0);
+			doc->runHooks("NewFromTemplate");
 		}
 	}
 }
@@ -344,34 +584,93 @@ void TWApp::openRecentFile()
 {
 	QAction *action = qobject_cast<QAction *>(sender());
 	if (action)
-		open(action->data().toString());
+		openFile(action->data().toString());
+}
+
+QStringList TWApp::getOpenFileNames(QString selectedFilter)
+{
+	QFileDialog::Options	options = 0;
+#ifdef Q_WS_WIN
+	if(TWApp::GetWindowsVersion() < 0x06000000) options |= QFileDialog::DontUseNativeDialog;
+#endif
+	QSETTINGS_OBJECT(settings);
+	QString lastOpenDir = settings.value("openDialogDir").toString();
+	QStringList filters = *TWUtils::filterList();
+	if (!selectedFilter.isNull() && !filters.contains(selectedFilter))
+		filters.prepend(selectedFilter);
+	return QFileDialog::getOpenFileNames(NULL, QString(tr("Open File")), lastOpenDir,
+										 filters.join(";;"), &selectedFilter, options);
+}
+
+QString TWApp::getOpenFileName(QString selectedFilter)
+{
+	QFileDialog::Options	options = 0;
+#ifdef Q_WS_WIN
+	if(TWApp::GetWindowsVersion() < 0x06000000) options |= QFileDialog::DontUseNativeDialog;
+#endif
+	QSETTINGS_OBJECT(settings);
+	QString lastOpenDir = settings.value("openDialogDir").toString();
+	QStringList filters = *TWUtils::filterList();
+	if (!selectedFilter.isNull() && !filters.contains(selectedFilter))
+		filters.prepend(selectedFilter);
+	return QFileDialog::getOpenFileName(NULL, QString(tr("Open File")), lastOpenDir,
+										filters.join(";;"), &selectedFilter, options);
+}
+
+QString TWApp::getSaveFileName(const QString& defaultName)
+{
+	QFileDialog::Options	options = 0;
+#ifdef Q_WS_WIN
+	if(TWApp::GetWindowsVersion() < 0x06000000) options |= QFileDialog::DontUseNativeDialog;
+#endif
+	QString selectedFilter;
+	if (!TWUtils::filterList()->isEmpty())
+		selectedFilter = TWUtils::chooseDefaultFilter(defaultName, *(TWUtils::filterList()));
+		
+	QString fileName = QFileDialog::getSaveFileName(NULL, tr("Save File"), defaultName,
+													TWUtils::filterList()->join(";;"),
+													&selectedFilter, options);
+	if (!fileName.isEmpty()) {
+		// add extension from the selected filter, if unique and not already present
+		QRegExp re("\\(\\*(\\.[^ ]+)\\)");
+		if (re.indexIn(selectedFilter) >= 0) {
+			QString ext = re.cap(1);
+			if (!fileName.endsWith(ext, Qt::CaseInsensitive) && !fileName.endsWith("."))
+				fileName.append(ext);
+		}
+	}
+	return fileName;
 }
 
 void TWApp::open()
 {
 	QSETTINGS_OBJECT(settings);
-	QString lastOpenDir = settings.value("openDialogDir").toString();
-	QStringList files = QFileDialog::getOpenFileNames(NULL, QString(tr("Open File")), lastOpenDir, TWUtils::filterList()->join(";;"));
+	QStringList files = getOpenFileNames();
 	foreach (QString fileName, files) {
 		if (!fileName.isEmpty()) {
 			QFileInfo info(fileName);
 			settings.setValue("openDialogDir", info.canonicalPath());
-			open(fileName);
+			openFile(fileName);
 		}
 	}
 }
 
-void TWApp::open(const QString &fileName)
+QObject* TWApp::openFile(const QString &fileName, int pos /* = 0 */)
 {
 	if (TWUtils::isPDFfile(fileName)) {
 		PDFDocument *doc = PDFDocument::findDocument(fileName);
 		if (doc == NULL)
 			doc = new PDFDocument(fileName);
-		if (doc != NULL)
+		if (doc != NULL) {
+			if (pos > 0)
+				doc->widget()->goToPage(pos - 1);
 			doc->selectWindow();
+			return doc;
+		}
+		return NULL;
 	}
 	else
-		TeXDocument::openDocument(fileName);
+		return TeXDocument::openDocument(fileName, true, true, pos, 0, 0);
 }
 
 void TWApp::preferences()
@@ -449,7 +748,7 @@ bool TWApp::event(QEvent *event)
 {
 	switch (event->type()) {
 		case QEvent::FileOpen:
-			open(static_cast<QFileOpenEvent *>(event)->file());        
+			openFile(static_cast<QFileOpenEvent *>(event)->file());        
 			return true;
 		default:
 			return QApplication::event(event);
@@ -507,7 +806,7 @@ void TWApp::setDefaultPaths()
 	}
 }
 
-const QStringList TWApp::getBinaryPaths()
+const QStringList TWApp::getPrefsBinaryPaths()
 {
 	if (binaryPaths == NULL) {
 		binaryPaths = new QStringList;
@@ -536,12 +835,14 @@ void TWApp::setDefaultEngineList()
 	else
 		engineList->clear();
 	*engineList
+		<< Engine("LaTeXmk", "latexmk" EXE, QStringList("-e") << 
+				  "$pdflatex=q/pdflatex -synctex=1 %O %S/" << "-pdf" << "$fullname", true)
 		<< Engine("pdfTeX", "pdftex" EXE, QStringList("$synctexoption") << "$fullname", true)
 		<< Engine("pdfLaTeX", "pdflatex" EXE, QStringList("$synctexoption") << "$fullname", true)
 		<< Engine("XeTeX", "xetex" EXE, QStringList("$synctexoption") << "$fullname", true)
 		<< Engine("XeLaTeX", "xelatex" EXE, QStringList("$synctexoption") << "$fullname", true)
-		<< Engine("ConTeXt", "texmfstart" EXE, QStringList("texexec") << "$fullname", true)
-		<< Engine("XeConTeXt", "texmfstart" EXE, QStringList("texexec") << "--xtx" << "$fullname", true)
+		<< Engine("ConTeXt (MKII)", "texmfstart" EXE, QStringList("texexec") << "--synctex" << "$fullname", true)
+		<< Engine("XeConTeXt (MKII)", "texmfstart" EXE, QStringList("texexec") << "--xtx" << "--synctex" << "$fullname", true)
 		<< Engine("BibTeX", "bibtex" EXE, QStringList("$basename"), false)
 		<< Engine("MakeIndex", "makeindex" EXE, QStringList("$basename"), false);
 	defaultEngineIndex = 1;
@@ -594,7 +895,7 @@ const QList<Engine> TWApp::getEngineList()
 
 		if (!foundList)
 			setDefaultEngineList();
-		setDefaultEngine(settings.value("defaultEngine").toString());
+		setDefaultEngine(settings.value("defaultEngine", DEFAULT_ENGINE_NAME).toString());
 	}
 	return *engineList;
 }
@@ -664,11 +965,6 @@ const Engine TWApp::getNamedEngine(const QString& name)
 	return Engine();
 }
 
-void TWApp::syncFromSource(const QString& sourceFile, int lineNo)
-{
-	emit syncPdf(sourceFile, lineNo);
-}
-
 QTextCodec *TWApp::getDefaultCodec()
 {
 	return defaultCodec;
@@ -731,23 +1027,48 @@ void TWApp::applyTranslation(const QString& locale)
 	emit updatedTranslators();
 }
 
-void TWApp::addToRecentFiles(const QString& fileName)
+void TWApp::addToRecentFiles(const QMap<QString,QVariant>& fileProperties)
 {
-	QFileInfo info(fileName);
-	QString canonical = info.canonicalFilePath();
-	if (canonical.isEmpty())
-		return;
-
 	QSETTINGS_OBJECT(settings);
-	QStringList files = settings.value("recentFileList").toStringList();
-	files.removeAll(fileName);
-	files.prepend(fileName);
-	while (files.size() > maxRecentFiles())
-		files.removeLast();
-	settings.setValue("recentFileList", files);
+
+	QString fileName = fileProperties.value("path").toString();
+	if (fileName.isEmpty())
+		return;
+	
+	QList<QVariant> fileList = settings.value("recentFiles").toList();
+	QList<QVariant>::iterator i = fileList.begin();
+	while (i != fileList.end()) {
+		QMap<QString,QVariant> h = i->toMap();
+		if (h.value("path").toString() == fileName)
+			i = fileList.erase(i);
+		else
+			++i;
+	}
+
+	fileList.prepend(fileProperties);
+
+	while (fileList.size() > maxRecentFiles())
+		fileList.removeLast();
+
+	settings.setValue("recentFiles", QVariant::fromValue(fileList));
+
 	updateRecentFileActions();
 }
 
+QMap<QString,QVariant> TWApp::getFileProperties(const QString& path)
+{
+	QSETTINGS_OBJECT(settings);
+	QList<QVariant> fileList = settings.value("recentFiles").toList();
+	QList<QVariant>::iterator i = fileList.begin();
+	while (i != fileList.end()) {
+		QMap<QString,QVariant> h = i->toMap();
+		if (h.value("path").toString() == path)
+			return h;
+		++i;
+	}
+	return QMap<QString,QVariant>();
+}
+
 void TWApp::openHelpFile(const QString& helpDirName)
 {
 	QDir helpDir(helpDirName);
@@ -757,6 +1078,18 @@ void TWApp::openHelpFile(const QString& helpDirName)
 		QMessageBox::warning(NULL, TEXWORKS_NAME, tr("Unable to find help file."));
 }
 
+void TWApp::updateScriptsList()
+{
+	scriptManager->reloadScripts();
+
+	emit scriptListChanged();
+}
+
+void TWApp::showScriptsFolder()
+{
+	QDesktopServices::openUrl(QUrl::fromLocalFile(TWUtils::getLibraryPath("scripts")));
+}
+
 #ifdef Q_WS_WIN	// support for the Windows single-instance code
 #include <windows.h>
 
@@ -769,8 +1102,11 @@ LRESULT CALLBACK TW_HiddenWindowProc(HWND hwnd, UINT uMsg, WPARAM wParam, LPARAM
 				const COPYDATASTRUCT* pcds = (const COPYDATASTRUCT*)lParam;
 				if (pcds->dwData == TW_OPEN_FILE_MSG) {
 					if (TWApp::instance() != NULL) {
-						QString fileName = QString::fromLocal8Bit((const char*)pcds->lpData, pcds->cbData);
-						TWApp::instance()->open(fileName);
+						QStringList data = QString::fromUtf8((const char*)pcds->lpData, pcds->cbData).split('\n');
+						if (data.size() == 1)
+							TWApp::instance()->openFile(data[0]);
+						else
+							TWApp::instance()->openFile(data[0], data[1].toInt());
 					}
 				}
 			}
@@ -832,3 +1168,112 @@ void TWApp::bringToFront()
 }
 #endif
 
+QList<QVariant> TWApp::getOpenWindows() const
+{
+	QList<QVariant> result;
+	
+	foreach (QWidget *widget, QApplication::topLevelWidgets()) {
+		if (qobject_cast<TWScriptable*>(widget))
+			result << QVariant::fromValue(qobject_cast<QObject*>(widget));
+	}
+	return result;
+}
+
+void TWApp::setGlobal(const QString& key, const QVariant& val)
+{
+	QVariant v = val;
+	
+	if (key.isEmpty())
+		return;
+	
+	// For objects on the heap make sure we are notified when their lifetimes
+	// end so that we can remove them from our hash accordingly
+	switch (val.type()) {
+		case QMetaType::QObjectStar:
+			connect(v.value<QObject*>(), SIGNAL(destroyed(QObject*)), this, SLOT(globalDestroyed(QObject*)));
+			break;
+		case QMetaType::QWidgetStar:
+			connect((QWidget*)v.data(), SIGNAL(destroyed(QObject*)), this, SLOT(globalDestroyed(QObject*)));
+			break;
+		default: break;
+	}
+	m_globals[key] = v;
+}
+
+void TWApp::globalDestroyed(QObject * obj)
+{
+	QHash<QString, QVariant>::iterator i = m_globals.begin();
+	
+	while (i != m_globals.end()) {
+		switch (i.value().type()) {
+			case QMetaType::QObjectStar:
+				if (i.value().value<QObject*>() == obj)
+					i = m_globals.erase(i);
+				else
+					++i;
+				break;
+			case QMetaType::QWidgetStar:
+				if (i.value().value<QWidget*>() == obj)
+					i = m_globals.erase(i);
+				else
+					++i;
+				break;
+			default:
+				++i;
+				break;
+		}
+	}
+}
+
+/*Q_INVOKABLE static*/
+int TWApp::getVersion()
+{
+	return (VER_MAJOR << 16) | (VER_MINOR << 8) | VER_BUGFIX;
+}
+
+//Q_INVOKABLE
+QMap<QString, QVariant> TWApp::openFileFromScript(const QString& fileName, QObject * scriptApiObj, const int pos /* = -1 */, const bool askUser /* = false */)
+{
+	QSETTINGS_OBJECT(settings);
+	QMap<QString, QVariant> retVal;
+	QObject * doc = NULL;
+	TWScript * script;
+	QFileInfo fi(fileName);
+	TWScriptAPI * scriptApi = qobject_cast<TWScriptAPI*>(scriptApiObj);
+
+	retVal["status"] = TWScriptAPI::SystemAccess_PermissionDenied;
+
+	// for absolute paths and full reading permissions, we don't have to care
+	// about peculiarities of the script; in that case, this even succeeds
+	// if no valid scriptApi is passed; otherwise, we need to investigate further
+	if (fi.isRelative() || !settings.value("allowScriptFileReading", false).toBool()) {
+		if (!scriptApi)
+			return retVal;
+		script = qobject_cast<TWScript*>(scriptApi->GetScript());
+		if (!script)
+			return retVal; // this should never happen
+	
+		// relative paths are taken to be relative to the folder containing the
+		// executing script's file
+		QDir scriptDir(QFileInfo(script->getFilename()).dir());
+		QString path = scriptDir.absoluteFilePath(fileName);
+	
+		if (!script->mayReadFile(path, scriptApi->GetTarget())) {
+			// Possibly ask user to override the permissions
+			if (!askUser)
+				return retVal;
+			if (QMessageBox::warning(qobject_cast<QWidget*>(scriptApi->GetTarget()), 
+				tr("Permission request"),
+				tr("The script \"%1\" is trying to open the file \"%2\" without sufficient permissions. Do you want to open the file?")\
+					.arg(script->getTitle()).arg(path),
+				QMessageBox::Yes | QMessageBox::No, QMessageBox::No
+			) != QMessageBox::Yes)
+				return retVal;
+		}
+	}
+	doc = openFile(fileName, pos);
+	retVal["result"] = QVariant::fromValue(doc);
+	retVal["status"] = (doc != NULL ? TWScriptAPI::SystemAccess_OK : TWScriptAPI::SystemAccess_Failed);
+	return retVal;
+}
+
