@@ -1,6 +1,6 @@
 /*
 	This is part of TeXworks, an environment for working with TeX documents
-	Copyright (C) 2007-08  Jonathan Kew
+	Copyright (C) 2007-2011  Jonathan Kew, Stefan Löffler
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -37,9 +37,21 @@
 #include <QFile>
 #include <QDirIterator>
 #include <QSignalMapper>
+#include <QCryptographicHash>
+#include <QTextStream>
 
 #pragma mark === TWUtils ===
 
+#ifdef Q_WS_X11
+// compile-time default paths - customize by defining in the .pro file
+#ifndef TW_DICPATH
+#define TW_DICPATH "/usr/share/myspell/dicts"
+#endif
+#ifndef TW_HELPPATH
+#define TW_HELPPATH "/usr/local/share/texworks-help"
+#endif
+#endif
+
 bool TWUtils::isPDFfile(const QString& fileName)
 {
 	QFile theFile(fileName);
@@ -70,65 +82,153 @@ bool TWUtils::isPostscriptFile(const QString& fileName)
 
 const QString TWUtils::getLibraryPath(const QString& subdir)
 {
-	QString libPath;
+	QString libRootPath, libPath;
 	
-	libPath = TWApp::instance()->getPortableLibPath();
-	if (!libPath.isEmpty()) {
-		libPath = QDir(libPath).absolutePath() + QDir::separator() + subdir;
-	}
-	else {
+	libRootPath = TWApp::instance()->getPortableLibPath();
+	if (libRootPath.isEmpty()) {
 #ifdef Q_WS_MAC
-		libPath = QDir::homePath() + "/Library/" + TEXWORKS_NAME + "/" + subdir;
+		libRootPath = QDir::homePath() + "/Library/" + TEXWORKS_NAME + "/";
 #endif
 #ifdef Q_WS_X11
-		if (subdir == "dictionaries")
-			libPath = "/usr/share/myspell/dicts";
+		if (subdir == "dictionaries") {
+			libPath = TW_DICPATH;
+			const char* dicPath = getenv("TW_DICPATH");
+			if (dicPath != NULL)
+				libPath = dicPath;
+			return libPath; // don't try to create/update the system dicts directory
+		}
 		else
-			libPath = QDir::homePath() + "/." + TEXWORKS_NAME + "/" + subdir;
+			libRootPath = QDir::homePath() + "/." + TEXWORKS_NAME + "/";
 #endif
 #ifdef Q_WS_WIN
-		libPath = QDir::homePath() + "/" + TEXWORKS_NAME + "/" + subdir;
+		libRootPath = QDir::homePath() + "/" + TEXWORKS_NAME + "/";
 #endif
 	}
-	// check if libPath exists
-	QFileInfo info(libPath);
-	if (!info.exists()) {
-		// create libPath
-		if (QDir::root().mkpath(libPath)) {
-			if (subdir != "translations") { // don't copy the built-in translations
-				QString cwd = QDir::currentPath();
-				if (QDir::setCurrent(libPath)) {
-					// copy default contents from app resources into the library dir
-					QDir resDir(":/resfiles/" + subdir);
-					copyResources(resDir, libPath);
-				}
-				QDir::setCurrent(cwd);
-			}
-		}
-	}
-	
+	libPath = QDir(libRootPath).absolutePath() + QDir::separator() + subdir;
+
+	updateLibraryResources(QDir(":/resfiles"), libRootPath, subdir);
 	return libPath;
 }
 
-void TWUtils::copyResources(const QDir& resDir, const QString& libPath)
+/*static*/
+void TWUtils::updateLibraryResources(const QDir& srcRootDir, const QDir& destRootDir, const QString& subdir)
 {
-	QDirIterator iter(resDir, QDirIterator::Subdirectories);
+	QDir srcDir(srcRootDir);
+	QDir destDir(destRootDir.absolutePath() + QDir::separator() + subdir);
+	
+	// make sure the library folder exists - even if the user deleted it;
+	// otherwise other parts of the program might fail
+	if (!destDir.exists())
+		QDir::root().mkpath(destDir.absolutePath());
+	
+	// sanity check
+	if (!srcDir.cd(subdir))
+		return;
+
+	if (subdir == "translations") // don't copy the built-in translations
+		return;
+	
+	FileVersionDatabase fvdb = FileVersionDatabase::load(destRootDir.absoluteFilePath("TwFileVersions.db"));
+	
+	QDirIterator iter(srcDir, QDirIterator::Subdirectories);
 	while (iter.hasNext()) {
 		(void)iter.next();
+		// Skip directories (they get created on-the-fly if required for copying files)
 		if (iter.fileInfo().isDir())
 			continue;
-		QString destPath = iter.fileInfo().canonicalPath();
-		destPath.replace(resDir.path(), libPath);
-		QFileInfo dest(destPath);
-		if (!dest.exists())
-			if (!QDir::root().mkpath(destPath))
+
+		QString srcPath = iter.fileInfo().filePath();
+		QString path = srcRootDir.relativeFilePath(srcPath);
+		QString destPath = destRootDir.filePath(path);
+		
+		// Check if the file is in the database
+		if (fvdb.hasFileRecord(destPath)) {
+			FileVersionDatabase::Record rec = fvdb.getFileRecord(destPath);
+			// If we can't update the file, don't bother with the rest of the
+			// code
+			if (rec.version >= SVN_REVISION)
 				continue;
-		if (QDir::setCurrent(destPath)) {
-			QFile srcFile(iter.fileInfo().canonicalFilePath());
-			srcFile.copy(iter.fileName());
-			QDir::setCurrent(libPath);
+			
+			// If the file no longer exists on the disk, the user has deleted it
+			// Hence we won't recreate it, but we keep the database record to
+			// remember that this file was deleted by the user
+			if (!QFileInfo(destPath).exists())
+				continue;
+			
+			QByteArray srcHash = FileVersionDatabase::hashForFile(srcPath);
+			QByteArray destHash = FileVersionDatabase::hashForFile(destPath);
+			// If the file was modified, don't do anything, either
+			if (destHash != rec.hash) {
+				// The only exception is if the file on the disk matches the
+				// new file we would have installed. In this case, we reassume
+				// ownership of it. (This is the case if the user deleted the
+				// file, but later wants to resurrect it by downloading the
+				// latest version from the internet)
+				if (destHash != srcHash)
+					continue;
+				fvdb.addFileRecord(destPath, srcHash, SVN_REVISION);
+			}
+			else {
+				// The file matches the record in the database; update it
+				// (copying is only necessary if the contents has changed)
+				if (srcHash == destHash)
+					fvdb.addFileRecord(destPath, srcHash, SVN_REVISION);
+				else {
+					// we have to remove the file first as QFile::copy doesn't
+					// overwrite existing files
+					QFile::remove(destPath);
+					if(QFile::copy(srcPath, destPath))
+						fvdb.addFileRecord(destPath, srcHash, SVN_REVISION);
+				}
+			}
+		}
+		else {
+			QByteArray srcHash = FileVersionDatabase::hashForFile(srcPath);
+			// If the file is not in the database, we add it - unless a file
+			// with the name already exists
+			if (!QFileInfo(destPath).exists()) {
+				// We have to make sure the directory exists - otherwise copying
+				// might fail
+				destRootDir.mkpath(QFileInfo(destPath).path());
+				QFile(srcPath).copy(destPath);
+				fvdb.addFileRecord(destPath, srcHash, SVN_REVISION);
+			}
+			else {
+				// If a file with that name already exists, we don't replace it
+				// If it happens to be identical with the version we would install
+				// we do take ownership, however, and register it in the
+				// database so that future updates are applied
+				QByteArray destHash = FileVersionDatabase::hashForFile(destPath);
+				if (srcHash == destHash)
+					fvdb.addFileRecord(destPath, destHash, SVN_REVISION);
+			}
 		}
 	}
+
+	// Now, remove all files that are unmodified on disk and were
+	// removed upstream
+	QMutableListIterator<FileVersionDatabase::Record> recIt(fvdb.getFileRecords());
+	while (recIt.hasNext()) {
+		const FileVersionDatabase::Record & rec = recIt.next();
+
+		QString destPath = rec.filePath.filePath();
+		QString path = destRootDir.relativeFilePath(destPath);
+		QString srcPath = srcRootDir.filePath(path);
+		
+		// If the source file still exists there is nothing to do here
+		if (QFileInfo(srcPath).exists())
+			continue;
+		
+		// If the source file no longer exists but the file on disk is up to
+		// date, remove it
+		if (rec.filePath.exists() && FileVersionDatabase::hashForFile(destPath) == rec.hash) {
+			QFile(destPath).remove();
+			recIt.remove();
+		}
+	}
+
+	// Finally, save the updated database
+	fvdb.save(destRootDir.absoluteFilePath("TwFileVersions.db"));
 }
 
 static int
@@ -180,11 +280,7 @@ void TWUtils::insertHelpMenuItems(QMenu* helpMenu)
 	QDir helpDir(QCoreApplication::applicationDirPath() + "/texworks-help");
 #ifdef Q_WS_X11
 	if (!helpDir.exists())
-#ifdef TW_HELPPATH
 		helpDir.cd(TW_HELPPATH);
-#else
-		helpDir.cd("/usr/local/share/texworks-help");
-#endif // defined(TW_HELPPATH)
 #endif
 #endif
 	const char* helpPath = getenv("TW_HELPPATH");
@@ -292,23 +388,30 @@ QStringList* TWUtils::getTranslationList()
 			*translationList << locName;
 	}
 	
+	// English is always available, and it has to be the first item
+	translationList->removeAll("en");
+	translationList->prepend("en");
+	
 	return translationList;
 }
 
-QStringList* TWUtils::dictionaryList = NULL;
+QHash<QString, QString>* TWUtils::dictionaryList = NULL;
 
-QStringList* TWUtils::getDictionaryList()
+QHash<QString, QString>* TWUtils::getDictionaryList(const bool forceReload /* = false */)
 {
-	if (dictionaryList != NULL)
-		return dictionaryList;
+	if (dictionaryList != NULL) {
+		if (!forceReload)
+			return dictionaryList;
+		delete dictionaryList;
+	}
 
-	dictionaryList = new QStringList;
+	dictionaryList = new QHash<QString, QString>();
 	QDir dicDir(TWUtils::getLibraryPath("dictionaries"));
-	foreach (QFileInfo affFileInfo, dicDir.entryInfoList(QStringList("*.aff"),
+	foreach (QFileInfo dicFileInfo, dicDir.entryInfoList(QStringList("*.dic"),
 				QDir::Files | QDir::Readable, QDir::Name | QDir::IgnoreCase)) {
-		QFileInfo dicFileInfo(affFileInfo.dir(), affFileInfo.completeBaseName() + ".dic");
-		if (dicFileInfo.isReadable())
-			*dictionaryList << dicFileInfo.completeBaseName();
+		QFileInfo affFileInfo(dicFileInfo.dir(), dicFileInfo.completeBaseName() + ".aff");
+		if (affFileInfo.isReadable())
+			dictionaryList->insertMulti(dicFileInfo.canonicalFilePath(), dicFileInfo.completeBaseName());
 	}
 	
 	return dictionaryList;
@@ -356,11 +459,28 @@ void TWUtils::setDefaultFilters()
 	*filters << QObject::tr("Auxiliary files (*.aux *.toc *.lot *.lof *.nav *.out *.snm *.ind *.idx *.bbl *.log)");
 	*filters << QObject::tr("Text files (*.txt)");
 	*filters << QObject::tr("PDF documents (*.pdf)");
-#ifdef Q_WS_WIN
-	*filters << QObject::tr("All files") + " (*.*)";	// unfortunately this doesn't work nicely on OS X or X11
-#else
-	*filters << QObject::tr("All files") + " (*)";
-#endif
+	*filters << QObject::tr("All files") + " (*)"; // this must not be "*.*", which causes an extension ".*" to be added on some systems
+}
+
+/*static*/
+QString TWUtils::chooseDefaultFilter(const QString & filename, const QStringList & filters)
+{
+	QString extension = QFileInfo(filename).completeSuffix();
+
+	if (extension.isEmpty())
+		return filters[0];
+	
+	QRegExp re("\\*\\." + QRegExp::escape(extension));
+	foreach (QString filter, filters) {
+		// return filter if it corresponds to the given extension
+		// note that the extension must be the first one in the list to match;
+		// otherwise, the file dialog would replace the actual extension by the
+		// first one in the list, thereby altering it without cause
+		if (filter.contains(QString("(*.%1").arg(extension)))
+			return filter;
+	}
+	// if no filter matched, return the last one (which should be "All files")
+	return filters.last();
 }
 
 QString TWUtils::strippedName(const QString &fullFileName)
@@ -371,8 +491,31 @@ QString TWUtils::strippedName(const QString &fullFileName)
 void TWUtils::updateRecentFileActions(QObject *parent, QList<QAction*> &actions, QMenu *menu) /* static */
 {
 	QSETTINGS_OBJECT(settings);
-	QStringList files = settings.value("recentFileList").toStringList();
-	int numRecentFiles = files.size();
+	QStringList fileList;
+	if (settings.contains("recentFiles")) {
+		QList<QVariant> files = settings.value("recentFiles").toList();
+		foreach (const QVariant& v, files) {
+			QMap<QString,QVariant> map = v.toMap();
+			if (map.contains("path"))
+				fileList.append(map.value("path").toString());
+		}
+	}
+	else {
+		// check for an old "recentFilesList" entry, and migrate it
+		if (settings.contains("recentFileList")) {
+			fileList = settings.value("recentFileList").toStringList();
+			QList<QVariant> files;
+			foreach (const QString& path, fileList) {
+				QMap<QString,QVariant> map;
+				map.insert("path", path);
+				files.append(QVariant(map));
+			}
+			settings.remove("recentFileList");
+			settings.setValue("recentFiles", files);
+		}
+	}
+	
+	int numRecentFiles = fileList.size();
 
 	while (actions.size() < numRecentFiles) {
 		QAction *act = new QAction(parent);
@@ -388,9 +531,10 @@ void TWUtils::updateRecentFileActions(QObject *parent, QList<QAction*> &actions,
 	}
 
 	for (int i = 0; i < numRecentFiles; ++i) {
-		QString text = TWUtils::strippedName(files[i]);
+		QString path = fileList[i];
+		QString text = TWUtils::strippedName(path);
 		actions[i]->setText(text);
-		actions[i]->setData(files[i]);
+		actions[i]->setData(path);
 		actions[i]->setVisible(true);
 	}
 }
@@ -413,7 +557,13 @@ void TWUtils::updateWindowMenu(QWidget *window, QMenu *menu) /* static */
 		if (first && !menu->actions().isEmpty())
 			menu->addSeparator();
 		first = false;
-		SelWinAction *selWin = new SelWinAction(menu, texDoc->fileName());
+		QString label = texDoc->fileName();
+		SelWinAction *selWin = new SelWinAction(menu, label);
+		if (texDoc->isModified()) {
+			QFont f(selWin->font());
+			f.setItalic(true);
+			selWin->setFont(f);
+		}
 		if (texDoc == qobject_cast<TeXDocument*>(window)) {
 			selWin->setCheckable(true);
 			selWin->setChecked(true);
@@ -477,6 +627,41 @@ void TWUtils::zoomToHalfScreen(QWidget *window, bool rhs)
 	QRect r = desktop->availableGeometry(window);
 	int wDiff = window->frameGeometry().width() - window->width();
 	int hDiff = window->frameGeometry().height() - window->height();
+
+	if (hDiff == 0 && wDiff == 0) {
+		// window may not be decorated yet, so we don't know how large
+		// the title bar etc. is. Try to extrapolate from other top-level
+		// windows (if some are available). We assume that if either
+		// hDiff or wDiff is non-zero, we have found a decorated window
+		// and can use its values.
+		foreach (QWidget * widget, QApplication::topLevelWidgets()) {
+			if (!qobject_cast<QMainWindow*>(widget))
+				continue;
+			hDiff = widget->frameGeometry().height() - widget->height();
+			wDiff = widget->frameGeometry().width() - widget->width();
+			if (hDiff != 0 || wDiff != 0)
+				break;
+		}
+		if (hDiff == 0 && wDiff == 0) {
+			// Give the user the possibility to specify his own values by
+			// hacking the config files.
+			// (Note: this should only be necessary in some special cases, e.g.
+			// on X11 systems with special effects enabled)
+			QSETTINGS_OBJECT(settings);
+			wDiff = qMax(0, settings.value("windowWDiff", 0).toInt());
+			hDiff = qMax(0, settings.value("windowHDiff", 0).toInt());
+		}
+		// If we still have no valid value for hDiff/wDiff, just guess (on some
+		// platforms)
+		if (hDiff == 0 && wDiff == 0) {
+#ifdef Q_WS_WIN
+			// (these values were determined on WinXP with default theme)
+			hDiff = 34;
+			wDiff = 8;
+#endif
+		}
+	}
+	
 	if (rhs) {
 		r.setLeft(r.left() + r.right() / 2);
 		window->move(r.left(), r.top());
@@ -491,8 +676,20 @@ void TWUtils::zoomToHalfScreen(QWidget *window, bool rhs)
 
 void TWUtils::sideBySide(QWidget *window1, QWidget *window2)
 {
-	zoomToHalfScreen(window1, false);
-	zoomToHalfScreen(window2, true);
+	QDesktopWidget *desktop = QApplication::desktop();
+
+	// if the windows reside on the same screen zoom each so that it occupies 
+	// half of that screen
+	if (desktop->screenNumber(window1) == desktop->screenNumber(window2)) {
+		zoomToHalfScreen(window1, false);
+		zoomToHalfScreen(window2, true);
+	}
+	// if the windows reside on different screens zoom each so that it uses
+	// its whole screen
+	else {
+		zoomToScreen(window1);
+		zoomToScreen(window2);
+	}
 }
 
 void TWUtils::tileWindowsInRect(const QWidgetList& windows, const QRect& bounds)
@@ -1008,3 +1205,115 @@ void Engine::setShowPdf(bool showPdf)
 {
 	f_showPdf = showPdf;
 }
+
+/*static*/
+FileVersionDatabase FileVersionDatabase::load(const QString & path)
+{
+	QFile fin(path);
+	FileVersionDatabase retVal;
+	QDir rootDir(QFileInfo(path).absoluteDir());
+	
+	if (!fin.open(QIODevice::ReadOnly | QIODevice::Text))
+		return retVal;
+
+	QTextStream strm(&fin);
+	
+	while (!strm.atEnd()) {
+		FileVersionDatabase::Record rec;
+		QString line = strm.readLine().trimmed();
+		
+		// ignore comments
+		if (line.startsWith('#')) continue;
+		
+		rec.version = line.section(' ', 0, 0).toUInt();
+		rec.hash = QByteArray::fromHex(line.section(' ', 1, 1).toAscii());
+		rec.filePath = line.section(' ', 2).trimmed();
+		rec.filePath = rootDir.absoluteFilePath(rec.filePath.filePath());
+		retVal.m_records.append(rec);
+	}
+	
+	fin.close();
+	
+	return retVal;
+}
+
+bool FileVersionDatabase::save(const QString & path) const
+{
+	QFile fout(path);
+	QDir rootDir(QFileInfo(path).absoluteDir());
+	
+	if (!fout.open(QIODevice::WriteOnly | QIODevice::Text))
+		return false;
+	
+	QTextStream strm(&fout);
+
+	foreach (FileVersionDatabase::Record rec, m_records) {
+		QString filePath = rec.filePath.absoluteFilePath();
+		strm << rec.version << " " << rec.hash.toHex() << " " << rootDir.relativeFilePath(filePath) << endl;
+	}
+	
+	fout.close();
+	return true;
+}
+
+void FileVersionDatabase::addFileRecord(const QFileInfo & file, const QByteArray & md5Hash, const unsigned int version)
+{
+	// remove all existing entries for this file
+	QMutableListIterator<FileVersionDatabase::Record> it(m_records);
+	
+	while (it.hasNext()) {
+		const FileVersionDatabase::Record rec = it.next();
+		if (file.absoluteFilePath() == rec.filePath.absoluteFilePath()) {
+			it.remove();
+		}
+	}
+	
+	// add the new data
+	FileVersionDatabase::Record rec;
+	rec.filePath = file;
+	rec.version = version;
+	rec.hash = md5Hash;
+	m_records.append(rec);
+}
+
+bool FileVersionDatabase::hasFileRecord(const QFileInfo & file) const
+{
+	QListIterator<FileVersionDatabase::Record> it(m_records);
+	
+	while (it.hasNext()) {
+		const FileVersionDatabase::Record rec = it.next();
+		if (file == rec.filePath)
+			return true;
+	}
+	return false;
+}
+
+FileVersionDatabase::Record FileVersionDatabase::getFileRecord(const QFileInfo & file) const
+{
+	QListIterator<FileVersionDatabase::Record> it(m_records);
+	
+	while (it.hasNext()) {
+		const FileVersionDatabase::Record rec = it.next();
+		if (file == rec.filePath)
+			return rec;
+	}
+
+	FileVersionDatabase::Record retVal;
+	retVal.version = 0;
+	retVal.hash = QByteArray::fromHex("d41d8cd98f00b204e9800998ecf8427e"); // hash for the zero-length string
+	return retVal;
+}
+
+/*static*/
+QByteArray FileVersionDatabase::hashForFile(const QString & path)
+{
+	QByteArray retVal = QByteArray::fromHex("d41d8cd98f00b204e9800998ecf8427e"); // hash for the zero-length string;
+	QFile fin(path);
+	
+	if (!fin.open(QIODevice::ReadOnly))
+		return retVal;
+	
+	retVal = QCryptographicHash::hash(fin.readAll(), QCryptographicHash::Md5);
+	fin.close();
+	return retVal;
+}
