@@ -38,6 +38,18 @@
         <source>Auxiliary files to be deleted:</source>
         <translation>補助ファイルは削除されました:</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished">全て選択</translation>
+    </message>
+    <message>
+        <source>Select None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Toggle</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FindDialog</name>
@@ -453,6 +465,59 @@
         <source>Ctrl+G</source>
         <translation>Ctrl+G</translation>
     </message>
+    <message>
+        <source>Scripts</source>
+        <translation>スクリプト</translation>
+    </message>
+    <message>
+        <source>Update Scripts</source>
+        <translation type="obsolete">スクリプトの更新</translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation>スクリプトの管理</translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation>スクリプトフォルダを開く</translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print Pdf...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+P</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do you want to open the file in the default viewer for printing instead?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> (remember to close it again to avoid access problems)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PDFFindDialog</name>
@@ -779,6 +844,46 @@
         <source>Auto-hide output panel unless errors occur</source>
         <translation>エラーがなければ、ログを表示しない</translation>
     </message>
+    <message>
+        <source>Smart Quotes mode:</source>
+        <translation>引用符の入力支援</translation>
+    </message>
+    <message>
+        <source> px</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation type="unfinished">スクリプト</translation>
+    </message>
+    <message>
+        <source>Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to read all files (script and document files are always readable)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to write files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to run system commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable QtScript debugger</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -886,6 +991,57 @@
         <translation>正規表現(&amp;R)</translation>
     </message>
 </context>
+<context>
+    <name>ScriptManager</name>
+    <message>
+        <source>Manage Scripts</source>
+        <translation type="unfinished">スクリプトの管理</translation>
+    </message>
+    <message>
+        <source>Standalone Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hook Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Context: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Author: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Version: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shortcut: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Language: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hook: </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchResults</name>
     <message>
@@ -916,6 +1072,10 @@
         <source>Search Results</source>
         <translation>検索結果</translation>
     </message>
+    <message>
+        <source>Search Results - %1 (%2 found)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TWApp</name>
@@ -977,16 +1137,12 @@
     </message>
     <message>
         <source>&lt;br&gt;Version %1 (r.%2)</source>
-        <translation>&lt;br&gt;バージョン %1 (r.%2)</translation>
+        <translation type="obsolete">&lt;br&gt;バージョン %1 (r.%2)</translation>
     </message>
     <message>
         <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
         <translation></translation>
     </message>
-    <message>
-        <source>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; application framework by Qt Software, a division of Nokia Corporation.</source>
-        <translation></translation>
-    </message>
     <message>
         <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
         <translation></translation>
@@ -1047,6 +1203,103 @@
         <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.</source>
         <translation>TeX関連プログラムがインストールされたディレクトリが見つかりません。&lt;p&gt;&lt;small&gt;プロセスを起動するためには、お使いのTeXディストリビューションに合わせたディレクトリ設定を[設定]-[タイプセット]ダイアログでおこなっておく必要があります</translation>
     </message>
+    <message>
+        <source>Unable to find help file.</source>
+        <translation>ヘルプファイルが見つかりません</translation>
+    </message>
+    <message>
+        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save File</source>
+        <translation type="unfinished">ファイルの保存</translation>
+    </message>
+    <message>
+        <source>Permission request</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptAPI</name>
+    <message>
+        <source>Internal error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to execute system command: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error executing system command: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>System command execution is disabled (see Preferences)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&quot;%1&quot; could not be opened.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reading all files is disabled (see Preferences)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The file &quot;%1&quot; could not be opened for reading</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptable</name>
+    <message>
+        <source>unknown error</source>
+        <translation>不明なエラー</translation>
+    </message>
+    <message>
+        <source>Script &quot;%1&quot;: %2</source>
+        <translation>スクリプト &quot;%1&quot;: %2</translation>
+    </message>
+    <message>
+        <source>Script result</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripting languages currently available in this copy of %1:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWSystemCmd</name>
+    <message>
+        <source>ERROR: failure code %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ERROR: exit code %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TagsDock</name>
@@ -1087,7 +1340,7 @@
     </message>
     <message>
         <source>Cannot close window while tool is running</source>
-        <translation>処理が続いているため、ウィンドウを閉じることができません</translation>
+        <translation type="obsolete">処理が続いているため、ウィンドウを閉じることができません</translation>
     </message>
     <message>
         <source>Save File</source>
@@ -1109,7 +1362,7 @@ Do you want to save your changes?</source>
     <message>
         <source>Cannot read file &quot;%1&quot;:
 %2.</source>
-        <translation>ファイル&quot;%1&quot;が開けません: %2</translation>
+        <translation type="obsolete">ファイル&quot;%1&quot;が開けません: %2</translation>
     </message>
     <message>
         <source>Unrecognized encoding</source>
@@ -1125,7 +1378,7 @@ It will be interpreted as %3 instead, which may result in incorrect text.</sourc
     </message>
     <message>
         <source>File &quot;%1&quot; loaded (%2)</source>
-        <translation>ファイル&quot;%1&quot;が読み込まれました (%2)</translation>
+        <translation type="obsolete">ファイル&quot;%1&quot;が読み込まれました (%2)</translation>
     </message>
     <message>
         <source>File changed on disk</source>
@@ -1155,7 +1408,7 @@ Do you want to proceed with saving this file, overwriting the version on disk?</
         <source>The text encoding %1 requested for %2 is not supported.
 
 It will be saved as %3 instead, which may result in incorrect text.</source>
-        <translation>ファイル%2が要求する文字コード%1はサポートされていません。
+        <translation type="obsolete">ファイル%2が要求する文字コード%1はサポートされていません。
 
 かわりに%3として保存しますが、表示がおかしくなる場合があります</translation>
     </message>
@@ -1174,16 +1427,16 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
     <message>
         <source>Cannot write file &quot;%1&quot;:
 %2.</source>
-        <translation>ファイル&quot;%1&quot;に書き込めません:
+        <translation type="obsolete">ファイル&quot;%1&quot;に書き込めません:
 %2</translation>
     </message>
     <message>
         <source>File &quot;%1&quot; saved (%2)</source>
-        <translation>ファイル&quot;%1&quot;に保存されました(%2)</translation>
+        <translation type="obsolete">ファイル&quot;%1&quot;に保存されました(%2)</translation>
     </message>
     <message>
         <source>default encoding</source>
-        <translation>デフォルトの文字コード</translation>
+        <translation type="obsolete">デフォルトの文字コード</translation>
     </message>
     <message>
         <source>untitled-%1.tex</source>
@@ -1671,6 +1924,105 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
         <source>Line Numbers</source>
         <translation>行番号</translation>
     </message>
+    <message>
+        <source>Process interrupted by user</source>
+        <translation>処理はユーザによって中断されました</translation>
+    </message>
+    <message>
+        <source>Console output</source>
+        <translation>ログの表示</translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation>スクリプト</translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation>スクリプトフォルダを開く</translation>
+    </message>
+    <message>
+        <source>Update Scripts</source>
+        <translation type="obsolete">スクリプトの更新</translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation>スクリプトの管理</translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Follow Focus</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply to Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Alt+S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+D</source>
+        <comment>shortcut: Don&apos;t Save</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+R</source>
+        <comment>shortcut: Revert</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot read file &quot;%1&quot;:
+%2</source>
+        <translation type="unfinished">ファイル&quot;%1&quot;が開けません: %2 {1&quot;?} {2?}</translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; loaded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is constantly being modified by another program.
+
+Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot write file &quot;%1&quot;:
+%2</source>
+        <translation type="unfinished">ファイル&quot;%1&quot;に書き込めません:
+%2 {1&quot;?} {2?}</translation>
+    </message>
+    <message>
+        <source>Error writing file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TeXHighlighter</name>
@@ -1696,6 +2048,18 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
         <source>NewArgument</source>
         <translation>新しい引数</translation>
     </message>
+    <message>
+        <source>Select program file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The file &apos;%1&apos; is not executable!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ToolConfigDialog</name>
@@ -1719,5 +2083,9 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
         <source>View PDF after running</source>
         <translation>実行後、PDFを表示する</translation>
     </message>
+    <message>
+        <source>Browse...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
