@@ -38,6 +38,18 @@
         <source>Auxiliary files to be deleted:</source>
         <translation>Arquivos auxiliares que serão apagados:</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation type="unfinished">Selecionar Tudo</translation>
+    </message>
+    <message>
+        <source>Select None</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Toggle</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>FindDialog</name>
@@ -453,6 +465,55 @@
         <source>Ctrl+G</source>
         <translation></translation>
     </message>
+    <message>
+        <source>Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Print Pdf...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+P</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
+</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Do you want to open the file in the default viewer for printing instead?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source> (remember to close it again to avoid access problems)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>PDFFindDialog</name>
@@ -779,6 +840,46 @@
         <source>Auto-hide output panel unless errors occur</source>
         <translation>Ocultar automaticamente o painel de mensagens se não ocorrerem erros</translation>
     </message>
+    <message>
+        <source> px</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Smart Quotes mode:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Security</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to read all files (script and document files are always readable)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to write files</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Allow scripts to run system commands</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Debugging</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable QtScript debugger</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -886,6 +987,57 @@
         <translation>Expressões &amp;regulares</translation>
     </message>
 </context>
+<context>
+    <name>ScriptManager</name>
+    <message>
+        <source>Manage Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Standalone Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hook Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Context: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Author: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Version: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Shortcut: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Language: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Hook: </source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>SearchResults</name>
     <message>
@@ -916,6 +1068,10 @@
         <source>Search Results</source>
         <translation>Resultados da Busca</translation>
     </message>
+    <message>
+        <source>Search Results - %1 (%2 found)</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TWApp</name>
@@ -977,7 +1133,7 @@
     </message>
     <message>
         <source>&lt;br&gt;Version %1 (r.%2)</source>
-        <translation>&lt;br&gt;Versão %1 (r%2)</translation>
+        <translation type="obsolete">&lt;br&gt;Versão %1 (r%2)</translation>
     </message>
     <message>
         <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
@@ -985,7 +1141,7 @@
     </message>
     <message>
         <source>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; application framework by Qt Software, a division of Nokia Corporation.</source>
-        <translation>&lt;p&gt;Ambiente de desenvolvimento &lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; da Qt Software, uma divisão da Nokia Corporation.</translation>
+        <translation type="obsolete">&lt;p&gt;Ambiente de desenvolvimento &lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; da Qt Software, uma divisão da Nokia Corporation.</translation>
     </message>
     <message>
         <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
@@ -1051,6 +1207,99 @@
         <source>Unable to find help file.</source>
         <translation>Impossível achar arquivo de ajuda.</translation>
     </message>
+    <message>
+        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save File</source>
+        <translation type="unfinished">Salvar o arquivo</translation>
+    </message>
+    <message>
+        <source>Permission request</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptAPI</name>
+    <message>
+        <source>Internal error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Failed to execute system command: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error executing system command: %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>System command execution is disabled (see Preferences)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>&quot;%1&quot; could not be opened.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reading all files is disabled (see Preferences)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The file &quot;%1&quot; could not be opened for reading</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptable</name>
+    <message>
+        <source>Script &quot;%1&quot;: %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Script result</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>unknown error</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripting languages currently available in this copy of %1:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
+<context>
+    <name>TWSystemCmd</name>
+    <message>
+        <source>ERROR: failure code %1</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>ERROR: exit code %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TagsDock</name>
@@ -1091,7 +1340,7 @@
     </message>
     <message>
         <source>Cannot close window while tool is running</source>
-        <translation>Impossivel fechar janela enquanto a ferramenta está em execução</translation>
+        <translation type="obsolete">Impossivel fechar janela enquanto a ferramenta está em execução</translation>
     </message>
     <message>
         <source>Save File</source>
@@ -1114,7 +1363,7 @@ Você quer salvar suas mudanças?</translation>
     <message>
         <source>Cannot read file &quot;%1&quot;:
 %2.</source>
-        <translation>Impossível ler arquivo &quot;%1&quot;:
+        <translation type="obsolete">Impossível ler arquivo &quot;%1&quot;:
 %2.</translation>
     </message>
     <message>
@@ -1131,7 +1380,7 @@ Será interpretada como %3, o que poderá resultar em texto incorreto.</translat
     </message>
     <message>
         <source>File &quot;%1&quot; loaded (%2)</source>
-        <translation>Arquivo &quot;%1&quot; aberto (%2)</translation>
+        <translation type="obsolete">Arquivo &quot;%1&quot; aberto (%2)</translation>
     </message>
     <message>
         <source>File changed on disk</source>
@@ -1161,7 +1410,7 @@ Você quer continuar e salvar este arquivo, sobrescrevendo a versão do disco?</
         <source>The text encoding %1 requested for %2 is not supported.
 
 It will be saved as %3 instead, which may result in incorrect text.</source>
-        <translation>A codificação de texto %1 escolhida para %2 não é suportada.
+        <translation type="obsolete">A codificação de texto %1 escolhida para %2 não é suportada.
 
 O arquivo será salvo como %3, o que poderá resultar em texto incorreto.</translation>
     </message>
@@ -1180,16 +1429,16 @@ Se você continuar, eles serão substituídos por códigos-padrão. Em vez disso
     <message>
         <source>Cannot write file &quot;%1&quot;:
 %2.</source>
-        <translation>Impossível gravar arquivo &quot;%1&quot;:
+        <translation type="obsolete">Impossível gravar arquivo &quot;%1&quot;:
 %2.</translation>
     </message>
     <message>
         <source>File &quot;%1&quot; saved (%2)</source>
-        <translation>Arquivo &quot;%1&quot; salvo (%2)</translation>
+        <translation type="obsolete">Arquivo &quot;%1&quot; salvo (%2)</translation>
     </message>
     <message>
         <source>default encoding</source>
-        <translation>codificação padrão</translation>
+        <translation type="obsolete">codificação padrão</translation>
     </message>
     <message>
         <source>untitled-%1.tex</source>
@@ -1685,6 +1934,98 @@ Se você continuar, eles serão substituídos por códigos-padrão. Em vez disso
         <source>Line Numbers</source>
         <translation>Números de linha</translation>
     </message>
+    <message>
+        <source>Console output</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Follow Focus</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Apply to Selection</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+Alt+S</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+D</source>
+        <comment>shortcut: Don&apos;t Save</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Ctrl+R</source>
+        <comment>shortcut: Revert</comment>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot read file &quot;%1&quot;:
+%2</source>
+        <translation type="unfinished">Impossível ler arquivo &quot;%1&quot;:
+%2. {1&quot;?} {2?}</translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; loaded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>%1 is constantly being modified by another program.
+
+Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cannot write file &quot;%1&quot;:
+%2</source>
+        <translation type="unfinished">Impossível gravar arquivo &quot;%1&quot;:
+%2. {1&quot;?} {2?}</translation>
+    </message>
+    <message>
+        <source>Error writing file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TeXHighlighter</name>
@@ -1710,6 +2051,18 @@ Se você continuar, eles serão substituídos por códigos-padrão. Em vez disso
         <source>NewArgument</source>
         <translation>Novo Argumento</translation>
     </message>
+    <message>
+        <source>Select program file</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Invalid program</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The file &apos;%1&apos; is not executable!</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ToolConfigDialog</name>
@@ -1733,5 +2086,9 @@ Se você continuar, eles serão substituídos por códigos-padrão. Em vez disso
         <source>View PDF after running</source>
         <translation>Exibir PDF depois de executar</translation>
     </message>
+    <message>
+        <source>Browse...</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
