@@ -38,6 +38,18 @@
         <source>Auxiliary files to be deleted:</source>
         <translation>下列辅助文件将被删除：</translation>
     </message>
+    <message>
+        <source>Select All</source>
+        <translation>选择所有</translation>
+    </message>
+    <message>
+        <source>Select None</source>
+        <translation>选择无</translation>
+    </message>
+    <message>
+        <source>Toggle</source>
+        <translation>触发</translation>
+    </message>
 </context>
 <context>
     <name>FindDialog</name>
@@ -141,7 +153,7 @@
     </message>
     <message>
         <source>page %1 of %2</source>
-        <translation>第%1页　共%2页</translation>
+        <translation>页 %1/%2</translation>
     </message>
     <message>
         <source>%1%</source>
@@ -349,7 +361,7 @@
     </message>
     <message>
         <source>Preferences...</source>
-        <translation>选项</translation>
+        <translation>首选项</translation>
     </message>
     <message>
         <source>Stack</source>
@@ -453,6 +465,60 @@
         <comment>action</comment>
         <translation></translation>
     </message>
+    <message>
+        <source>Scripts</source>
+        <translation>脚本</translation>
+    </message>
+    <message>
+        <source>Update Scripts</source>
+        <translation type="obsolete">更新脚本</translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation>管理脚本</translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation>显示脚本文件夹</translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation>中止排版</translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation>TeXworks脚本</translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation>重载脚本列表</translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation>关于脚本...</translation>
+    </message>
+    <message>
+        <source>Print Pdf...</source>
+        <translation>打印 Pdf...</translation>
+    </message>
+    <message>
+        <source>Ctrl+P</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Unfortunately, this version of %1 is unable to print Pdf documents due to various technical reasons.
+</source>
+        <translation>很不幸，由于各种技术原因本版本 %1 无法打印 Pdf 文档。
+</translation>
+    </message>
+    <message>
+        <source>Do you want to open the file in the default viewer for printing instead?</source>
+        <translation>是否希望打开默认Pdf 查看器中的文件以打印？</translation>
+    </message>
+    <message>
+        <source> (remember to close it again to avoid access problems)</source>
+        <translation>（记住再一次关闭文档以避免出现访问问题）</translation>
+    </message>
 </context>
 <context>
     <name>PDFFindDialog</name>
@@ -605,7 +671,7 @@
     </message>
     <message>
         <source>TeXworks Preferences</source>
-        <translation>TeXworks 选项</translation>
+        <translation>TeXworks 首选项</translation>
     </message>
     <message>
         <source>General</source>
@@ -753,7 +819,7 @@
     </message>
     <message>
         <source>Processing tools</source>
-        <translation>处理工具？</translation>
+        <translation>处理工具</translation>
     </message>
     <message>
         <source>Edit...</source>
@@ -779,6 +845,46 @@
         <source>Highlight current line</source>
         <translation>高亮显示当前行</translation>
     </message>
+    <message>
+        <source>Smart Quotes mode:</source>
+        <translation>智能引号模式</translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation>脚本</translation>
+    </message>
+    <message>
+        <source>Enable QtScript debugger</source>
+        <translation>启用 QtScript 调试器</translation>
+    </message>
+    <message>
+        <source>Allow scripts to run system commands</source>
+        <translation>允许脚本运行系统命令</translation>
+    </message>
+    <message>
+        <source> px</source>
+        <translation>像素</translation>
+    </message>
+    <message>
+        <source>Security</source>
+        <translation>安全性</translation>
+    </message>
+    <message>
+        <source>Allow scripts to write files</source>
+        <translation>允许脚本写文件</translation>
+    </message>
+    <message>
+        <source>Enable plug-in scripting languages (may circumvent other restrictions on script behavior)</source>
+        <translation>打开插件脚本语言</translation>
+    </message>
+    <message>
+        <source>Debugging</source>
+        <translation>调试</translation>
+    </message>
+    <message>
+        <source>Allow scripts to read all files (script and document files are always readable)</source>
+        <translation>允许脚本读取所有文件（脚本和文档文件始终可读）</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -822,6 +928,11 @@
         <source>All files</source>
         <translation>所有文件</translation>
     </message>
+    <message>
+        <source>TeXworks %1r%2 (%3)
+</source>
+        <translation type="obsolete">TeXworks %1r%2 (%3)</translation>
+    </message>
 </context>
 <context>
     <name>ReplaceDialog</name>
@@ -886,6 +997,57 @@
         <translation>使用正则表达式 (&amp;R)</translation>
     </message>
 </context>
+<context>
+    <name>ScriptManager</name>
+    <message>
+        <source>Manage Scripts</source>
+        <translation>管理脚本</translation>
+    </message>
+    <message>
+        <source>Standalone Scripts</source>
+        <translation>独立脚本</translation>
+    </message>
+    <message>
+        <source>Hook Scripts</source>
+        <translation>钩子脚本</translation>
+    </message>
+    <message>
+        <source>Name: </source>
+        <translation>名称：</translation>
+    </message>
+    <message>
+        <source>Context: </source>
+        <translation>上下文：</translation>
+    </message>
+    <message>
+        <source>Description: </source>
+        <translation>描诉：</translation>
+    </message>
+    <message>
+        <source>Author: </source>
+        <translation>作者：</translation>
+    </message>
+    <message>
+        <source>Version: </source>
+        <translation>版本：</translation>
+    </message>
+    <message>
+        <source>Shortcut: </source>
+        <translation>快捷键：</translation>
+    </message>
+    <message>
+        <source>File: </source>
+        <translation>文件：</translation>
+    </message>
+    <message>
+        <source>Language: </source>
+        <translation>语言：</translation>
+    </message>
+    <message>
+        <source>Hook: </source>
+        <translation>钩子：</translation>
+    </message>
+</context>
 <context>
     <name>SearchResults</name>
     <message>
@@ -916,6 +1078,10 @@
         <source>Search Results</source>
         <translation>搜索结果</translation>
     </message>
+    <message>
+        <source>Search Results - %1 (%2 found)</source>
+        <translation>搜索结果 — %1（发现了 %2）</translation>
+    </message>
 </context>
 <context>
     <name>TWApp</name>
@@ -933,7 +1099,7 @@
     </message>
     <message>
         <source>Preferences...</source>
-        <translation>选项</translation>
+        <translation>首选项</translation>
     </message>
     <message>
         <source>Open...</source>
@@ -977,7 +1143,7 @@
     </message>
     <message>
         <source>&lt;br&gt;Version %1 (r.%2)</source>
-        <translation>&lt;br&gt; 版本 %1 (r.%2)</translation>
+        <translation type="obsolete">&lt;br&gt; 版本 %1 (r.%2)</translation>
     </message>
     <message>
         <source>&lt;p&gt;Distributed under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl-2.0.html&quot;&gt;GNU General Public License&lt;/a&gt;, version 2.</source>
@@ -985,7 +1151,7 @@
     </message>
     <message>
         <source>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; application framework by Qt Software, a division of Nokia Corporation.</source>
-        <translation>&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; 应用程序框架由诺基亚公司子公司 Qt 软件 开发。</translation>
+        <translation type="obsolete">&lt;p&gt;&lt;a href=&quot;http://trolltech.com/products/&quot;&gt;Qt4&lt;/a&gt; 应用程序框架由诺基亚公司子公司 Qt 软件 开发。</translation>
     </message>
     <message>
         <source>&lt;br&gt;&lt;a href=&quot;http://poppler.freedesktop.org/&quot;&gt;Poppler&lt;/a&gt; PDF rendering library by Kristian H&amp;#xF8;gsberg, Albert Astals Cid and others.</source>
@@ -1013,7 +1179,7 @@
     </message>
     <message>
         <source>[language name]</source>
-        <translation>简体中文 (Chinese Simplified)</translation>
+        <translation>简体中文 (Simplified Chinese)</translation>
     </message>
     <message>
         <source>[translator&apos;s name/email]</source>
@@ -1041,16 +1207,121 @@
     </message>
     <message>
         <source>No default binary directory found</source>
-        <translation>没有发现默认的 bin 目录</translation>
+        <translation>没有发现默认的可执行程序（bin）目录</translation>
     </message>
     <message>
         <source>None of the predefined directories for TeX-related programs could be found.&lt;p&gt;&lt;small&gt;To run any processes, you will need to set the binaries directory (or directories) for your TeX distribution using the Typesetting tab of the Preferences dialog.</source>
-        <translation>没有找到 TeX 相关程序所在的预定义目录。&lt;p&gt;&lt;small&gt;为了运行任何处理程序，你需要在＜选项＞对话框的＜排版＞选项卡中设定 TeX 系统的二进制程序目录 (bin)。</translation>
+        <translation>没有找到 TeX 相关程序所在的预定义目录。&lt;p&gt;&lt;small&gt;为了运行任何处理程序，你需要在＜首选项＞对话框的＜排版＞选项卡中设定 TeX 系统的二进制程序目录 (bin)。</translation>
     </message>
     <message>
         <source>Unable to find help file.</source>
         <translation>无法找到帮助文件。</translation>
     </message>
+    <message>
+        <source>Save File</source>
+        <translation>保存文件</translation>
+    </message>
+    <message>
+        <source>Failed to execute system command: %1</source>
+        <translation type="obsolete">无法执行系统命令：%1</translation>
+    </message>
+    <message>
+        <source>Error executing system command: %1</source>
+        <translation type="obsolete">系统命令执行错误：%1</translation>
+    </message>
+    <message>
+        <source>System command execution is disabled (see Preferences)</source>
+        <translation type="obsolete">系统命令执行被禁止（见＜首选项＞）</translation>
+    </message>
+    <message>
+        <source>&lt;br&gt;Version %1 r.%2 (%3)</source>
+        <translation>&lt;br&gt;版本 %1 r%2 (%3)</translation>
+    </message>
+    <message>
+        <source>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt application framework&lt;/a&gt; v%1 by Qt Software, a division of Nokia Corporation.</source>
+        <translation>&lt;p&gt;&lt;a href=&quot;http://qt.nokia.com/&quot;&gt;Qt应用程序框架&lt;/a&gt;v%1 由Nokia公司子公司 Qt Software 开发。</translation>
+    </message>
+    <message>
+        <source>Permission request</source>
+        <translation>请求权限</translation>
+    </message>
+    <message>
+        <source>The script &quot;%1&quot; is trying to open the file &quot;%2&quot; without sufficient permissions. Do you want to open the file?</source>
+        <translation>脚本 “%1&quot; 试图打开未授权文件 &quot;%2&quot;。你想打开此文件吗？</translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptAPI</name>
+    <message>
+        <source>Internal error</source>
+        <translation>内部错误</translation>
+    </message>
+    <message>
+        <source>Failed to execute system command: %1</source>
+        <translation>系统命令运行失败：%1 </translation>
+    </message>
+    <message>
+        <source>Error executing system command: %1</source>
+        <translation>系统命令运行错误：%1</translation>
+    </message>
+    <message>
+        <source>System command execution is disabled (see Preferences)</source>
+        <translation>运行系统命令已被禁止（见＜首选项＞）</translation>
+    </message>
+    <message>
+        <source>&quot;%1&quot; could not be opened.</source>
+        <translation>&quot;%1&quot; 无法打开。</translation>
+    </message>
+    <message>
+        <source>Reading all files is disabled (see Preferences)</source>
+        <translation>禁止读取所有文件（见首选项）</translation>
+    </message>
+    <message>
+        <source>The file &quot;%1&quot; could not be opened for reading</source>
+        <translation>文件 &quot;%1&quot; 无法打开以便读取内容。</translation>
+    </message>
+</context>
+<context>
+    <name>TWScriptable</name>
+    <message>
+        <source>unknown error</source>
+        <translation>未知错误</translation>
+    </message>
+    <message>
+        <source>Script &quot;%1&quot;: %2</source>
+        <translation>脚本 “%1”：%2</translation>
+    </message>
+    <message>
+        <source>Script result</source>
+        <translation>脚本执行结果</translation>
+    </message>
+    <message>
+        <source>Scripts may be used to add new commands to %1, and to extend or modify its behavior.</source>
+        <translation>脚本可用于添加新的命令到 %1，以及拓展或修改命令。</translation>
+    </message>
+    <message>
+        <source>For more information on creating and using scripts, see %1&lt;/p&gt;</source>
+        <translation>关于创建和使用脚本的更多信息，参见 %1&lt;/p&gt;</translation>
+    </message>
+    <message>
+        <source>Scripting languages currently available in this copy of %1:</source>
+        <translation>当前 %1 副本中支持的脚本语言：</translation>
+    </message>
+    <message>
+        <source>About Scripts</source>
+        <translation>关于脚本</translation>
+    </message>
+</context>
+<context>
+    <name>TWSystemCmd</name>
+    <message>
+        <source>ERROR: failure code %1</source>
+        <translation>错误：失败返回值为 %1</translation>
+    </message>
+    <message>
+        <source>ERROR: exit code %1</source>
+        <translation>错误：退出返回值为 %1</translation>
+    </message>
 </context>
 <context>
     <name>TagsDock</name>
@@ -1114,7 +1385,7 @@ Do you want to save your changes?</source>
     <message>
         <source>Cannot read file &quot;%1&quot;:
 %2.</source>
-        <translation>无法读入文件 &quot;%1&quot;:
+        <translation type="obsolete">无法读入文件 &quot;%1&quot;:
 %2.</translation>
     </message>
     <message>
@@ -1130,7 +1401,7 @@ It will be interpreted as %3 instead, which may result in incorrect text.</sourc
     </message>
     <message>
         <source>File &quot;%1&quot; loaded (%2)</source>
-        <translation>文件 &quot;%1&quot; 加载了 (%2)</translation>
+        <translation type="obsolete">文件 &quot;%1&quot; 加载了 (%2)</translation>
     </message>
     <message>
         <source>File changed on disk</source>
@@ -1158,7 +1429,7 @@ Do you want to proceed with saving this file, overwriting the version on disk?</
         <source>The text encoding %1 requested for %2 is not supported.
 
 It will be saved as %3 instead, which may result in incorrect text.</source>
-        <translation>&quot;%2&quot; 要求的文本编码 %1 不支持。
+        <translation type="obsolete">&quot;%2&quot; 要求的文本编码 %1 不支持。
 将使用 %3 替代，可能会导致不正确的文本。</translation>
     </message>
     <message>
@@ -1175,16 +1446,16 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
     <message>
         <source>Cannot write file &quot;%1&quot;:
 %2.</source>
-        <translation>无法写入文件 &quot;%1&quot;:
+        <translation type="obsolete">无法写入文件 &quot;%1&quot;:
 %2。</translation>
     </message>
     <message>
         <source>File &quot;%1&quot; saved (%2)</source>
-        <translation>文件 &quot;%1&quot; 已保存 (%2)</translation>
+        <translation type="obsolete">文件 &quot;%1&quot; 已保存 (%2)</translation>
     </message>
     <message>
         <source>default encoding</source>
-        <translation>默认编码</translation>
+        <translation type="obsolete">默认编码</translation>
     </message>
     <message>
         <source>untitled-%1.tex</source>
@@ -1196,7 +1467,7 @@ If you proceed, they will be replaced with default codes. Alternatively, you may
     </message>
     <message>
         <source>Line %1 of %2; col %3</source>
-        <translation>行 %1 of %2；列 %3</translation>
+        <translation>行 %1/%2；列 %3</translation>
     </message>
     <message>
         <source>Go to Line</source>
@@ -1559,7 +1830,7 @@ Check configuration of the %2 tool and path settings in the Preferences dialog.<
     </message>
     <message>
         <source>Preferences...</source>
-        <translation>选项</translation>
+        <translation>首选项</translation>
     </message>
     <message>
         <source>Go to Preview</source>
@@ -1663,7 +1934,7 @@ Check configuration of the %2 tool and path settings in the Preferences dialog.<
     </message>
     <message>
         <source>Check configuration of the %1 tool and path settings in the Preferences dialog.</source>
-        <translation>检查选项对话框中的  %1 的工具和路径设置。</translation>
+        <translation>检查＜首选项＞对话框中的  %1 的工具和路径设置。</translation>
     </message>
     <message>
         <source>Line Numbers</source>
@@ -1683,6 +1954,101 @@ Check configuration of the %2 tool and path settings in the Preferences dialog.<
         <comment>action</comment>
         <translation></translation>
     </message>
+    <message>
+        <source>Console output</source>
+        <translation>控制台输出</translation>
+    </message>
+    <message>
+        <source>Scripts</source>
+        <translation>脚本</translation>
+    </message>
+    <message>
+        <source>Show Scripts Folder</source>
+        <translation>显示脚本文件夹</translation>
+    </message>
+    <message>
+        <source>Update Scripts</source>
+        <translation type="obsolete">更新脚本</translation>
+    </message>
+    <message>
+        <source>Manage Scripts</source>
+        <translation>管理脚本</translation>
+    </message>
+    <message>
+        <source>Cannot read file &quot;%1&quot;:
+%2</source>
+        <translation>无法读入文件 &quot;%1&quot;: %2</translation>
+    </message>
+    <message>
+        <source>Cannot write file &quot;%1&quot;:
+%2</source>
+        <translation>无法写入文件 &quot;%1&quot;: %2</translation>
+    </message>
+    <message>
+        <source>Abort typesetting</source>
+        <translation>中止排版</translation>
+    </message>
+    <message>
+        <source>Auto-Follow Focus</source>
+        <translation>自动跟踪焦点</translation>
+    </message>
+    <message>
+        <source>Scripting TeXworks</source>
+        <translation>TeXworks 脚本</translation>
+    </message>
+    <message>
+        <source>Reload Script List</source>
+        <translation>重载脚本列表</translation>
+    </message>
+    <message>
+        <source>About Scripts...</source>
+        <translation>关于脚本...</translation>
+    </message>
+    <message>
+        <source>Apply to Selection</source>
+        <translation>应用至选择内容</translation>
+    </message>
+    <message>
+        <source>Save All</source>
+        <translation>保存全部</translation>
+    </message>
+    <message>
+        <source>Ctrl+Alt+S</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Ctrl+D</source>
+        <comment>shortcut: Don&apos;t Save</comment>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Ctrl+R</source>
+        <comment>shortcut: Revert</comment>
+        <translation></translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; loaded</source>
+        <translation>文件 &quot;%1&quot; 已加载</translation>
+    </message>
+    <message>
+        <source>Error writing file</source>
+        <translation>写文件错误</translation>
+    </message>
+    <message>
+        <source>An error may have occurred while saving the file. You might like to save a copy in a different location.</source>
+        <translation>保存文件时出错。你可以换个位置保存文件。</translation>
+    </message>
+    <message>
+        <source>File &quot;%1&quot; saved</source>
+        <translation>文件 &quot;%1&quot; 已保存</translation>
+    </message>
+    <message>
+        <source>%1 is constantly being modified by another program.
+
+Please use &quot;File &gt; Revert to Saved&quot; manually when the external process has finished.</source>
+        <translation>%1 经常被其它程序修改。
+请在外部程序完成后，手动执行“文件-&gt;恢复到已保存”命令重新载入%1。</translation>
+    </message>
 </context>
 <context>
     <name>TeXHighlighter</name>
@@ -1708,6 +2074,18 @@ Check configuration of the %2 tool and path settings in the Preferences dialog.<
         <source>NewArgument</source>
         <translation>新参数</translation>
     </message>
+    <message>
+        <source>Select program file</source>
+        <translation>选择程序文件</translation>
+    </message>
+    <message>
+        <source>Invalid program</source>
+        <translation>无效程序</translation>
+    </message>
+    <message>
+        <source>The file &apos;%1&apos; is not executable!</source>
+        <translation>&quot;%1&quot; 是非可执行文件</translation>
+    </message>
 </context>
 <context>
     <name>ToolConfigDialog</name>
@@ -1731,5 +2109,9 @@ Check configuration of the %2 tool and path settings in the Preferences dialog.<
         <source>View PDF after running</source>
         <translation>运行后查看 PDF 文件</translation>
     </message>
+    <message>
+        <source>Browse...</source>
+        <translation>浏览...</translation>
+    </message>
 </context>
 </TS>
